Class: Google::Apis::ThreatintelligenceV1beta::Alert

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

Stateful object representing a group of Findings. Key feature to an Alert is that it expresses the user's intent towards the findings of that group, even those that haven't occurred yet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Alert

Returns a new instance of Alert.



118
119
120
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_summaryString

Optional. AI summary of the finding. Corresponds to the JSON property aiSummary

Returns:

  • (String)


34
35
36
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 34

def ai_summary
  @ai_summary
end

#auditGoogle::Apis::ThreatintelligenceV1beta::Audit

Tracks basic CRUD facts. Corresponds to the JSON property audit



39
40
41
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 39

def audit
  @audit
end

#configurationsArray<String>

Output only. The resource names of the Configurations bound to this alert. Format: projects/project/configurations/configuration Corresponds to the JSON property configurations

Returns:

  • (Array<String>)


45
46
47
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 45

def configurations
  @configurations
end

#detailGoogle::Apis::ThreatintelligenceV1beta::AlertDetail

Container for different types of alert details. Corresponds to the JSON property detail



50
51
52
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 50

def detail
  @detail
end

#display_nameString

Output only. A short title for the alert. Corresponds to the JSON property displayName

Returns:

  • (String)


55
56
57
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 55

def display_name
  @display_name
end

#duplicate_ofString

Output only. alert name of the alert this alert is a duplicate of. Format: projects/project/alerts/alert Corresponds to the JSON property duplicateOf

Returns:

  • (String)


61
62
63
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 61

def duplicate_of
  @duplicate_of
end

#duplicated_byArray<String>

Output only. alert names of the alerts that are duplicates of this alert. Format: projects/project/alerts/alert Corresponds to the JSON property duplicatedBy

Returns:

  • (Array<String>)


67
68
69
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 67

def duplicated_by
  @duplicated_by
end

#etagString

Optional. If included when updating an alert, this should be set to the current etag of the alert. If the etags do not match, the update will be rejected and an ABORTED error will be returned. Corresponds to the JSON property etag

Returns:

  • (String)


74
75
76
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 74

def etag
  @etag
end

#external_idString

Output only. External ID for the alert. This is used internally to provide protection against out of order updates. Corresponds to the JSON property externalId

Returns:

  • (String)


80
81
82
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 80

def external_id
  @external_id
end

#finding_countFixnum

Output only. The number of findings associated with this alert. Corresponds to the JSON property findingCount

Returns:

  • (Fixnum)


85
86
87
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 85

def finding_count
  @finding_count
end

#findingsArray<String>

Output only. Findings that are covered by this alert. Corresponds to the JSON property findings

Returns:

  • (Array<String>)


90
91
92
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 90

def findings
  @findings
end

#nameString

Identifier. Server generated name for the alert. format is projects/project/ alerts/alert Corresponds to the JSON property name

Returns:

  • (String)


96
97
98
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 96

def name
  @name
end

#priority_analysisGoogle::Apis::ThreatintelligenceV1beta::PriorityAnalysis

Structured priority analysis for a threat. Corresponds to the JSON property priorityAnalysis



101
102
103
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 101

def priority_analysis
  @priority_analysis
end

#relevance_analysisGoogle::Apis::ThreatintelligenceV1beta::RelevanceAnalysis

Structured relevance analysis for a threat. Corresponds to the JSON property relevanceAnalysis



106
107
108
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 106

def relevance_analysis
  @relevance_analysis
end

#severity_analysisGoogle::Apis::ThreatintelligenceV1beta::SeverityAnalysis

Structured severity analysis for a threat. Corresponds to the JSON property severityAnalysis



111
112
113
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 111

def severity_analysis
  @severity_analysis
end

#stateString

Output only. State of the alert. Corresponds to the JSON property state

Returns:

  • (String)


116
117
118
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 116

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 123

def update!(**args)
  @ai_summary = args[:ai_summary] if args.key?(:ai_summary)
  @audit = args[:audit] if args.key?(:audit)
  @configurations = args[:configurations] if args.key?(:configurations)
  @detail = args[:detail] if args.key?(:detail)
  @display_name = args[:display_name] if args.key?(:display_name)
  @duplicate_of = args[:duplicate_of] if args.key?(:duplicate_of)
  @duplicated_by = args[:duplicated_by] if args.key?(:duplicated_by)
  @etag = args[:etag] if args.key?(:etag)
  @external_id = args[:external_id] if args.key?(:external_id)
  @finding_count = args[:finding_count] if args.key?(:finding_count)
  @findings = args[:findings] if args.key?(:findings)
  @name = args[:name] if args.key?(:name)
  @priority_analysis = args[:priority_analysis] if args.key?(:priority_analysis)
  @relevance_analysis = args[:relevance_analysis] if args.key?(:relevance_analysis)
  @severity_analysis = args[:severity_analysis] if args.key?(:severity_analysis)
  @state = args[:state] if args.key?(:state)
end