Class: Google::Apis::ThreatintelligenceV1beta::AlertDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

Container for different types of alert details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AlertDetail

Returns a new instance of AlertDetail.



168
169
170
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 168

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_leakGoogle::Apis::ThreatintelligenceV1beta::DataLeakAlertDetail

Captures the specific details of Data Leak alert. Corresponds to the JSON property dataLeak



150
151
152
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 150

def data_leak
  @data_leak
end

#detail_typeString

Output only. Name of the detail type. Will be set by the server during creation to the name of the field that is set in the detail union. Corresponds to the JSON property detailType

Returns:

  • (String)


156
157
158
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 156

def detail_type
  @detail_type
end

#initial_access_brokerGoogle::Apis::ThreatintelligenceV1beta::InitialAccessBrokerAlertDetail

Captures the specific details of InitialAccessBroker (IAB) alert. Corresponds to the JSON property initialAccessBroker



161
162
163
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 161

def initial_access_broker
  @initial_access_broker
end

#insider_threatGoogle::Apis::ThreatintelligenceV1beta::InsiderThreatAlertDetail

Captures the specific details of InsiderThreat alert. Corresponds to the JSON property insiderThreat



166
167
168
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 166

def insider_threat
  @insider_threat
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



173
174
175
176
177
178
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 173

def update!(**args)
  @data_leak = args[:data_leak] if args.key?(:data_leak)
  @detail_type = args[:detail_type] if args.key?(:detail_type)
  @initial_access_broker = args[:initial_access_broker] if args.key?(:initial_access_broker)
  @insider_threat = args[:insider_threat] if args.key?(:insider_threat)
end