Class: Google::Apis::ThreatintelligenceV1beta::AlertDocument
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::AlertDocument
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
A document that is associated with an alert.
Instance Attribute Summary collapse
-
#ai_summary ⇒ String
Output only.
-
#author ⇒ String
Output only.
-
#collection_time ⇒ String
Output only.
-
#content ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#ingest_time ⇒ String
Output only.
-
#language_code ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#source ⇒ String
Output only.
-
#source_update_time ⇒ String
Output only.
-
#source_uri ⇒ String
Output only.
-
#title ⇒ String
Output only.
-
#translation ⇒ Google::Apis::ThreatintelligenceV1beta::AlertDocumentTranslation
The translation of an alert document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AlertDocument
constructor
A new instance of AlertDocument.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AlertDocument
Returns a new instance of AlertDocument.
258 259 260 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 258 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ai_summary ⇒ String
Output only. AI summary of the document.
Corresponds to the JSON property aiSummary
194 195 196 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 194 def ai_summary @ai_summary end |
#author ⇒ String
Output only. The author of the document.
Corresponds to the JSON property author
199 200 201 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 199 def @author end |
#collection_time ⇒ String
Output only. Time when the origin source collected the intel.
Corresponds to the JSON property collectionTime
204 205 206 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 204 def collection_time @collection_time end |
#content ⇒ String
Output only. The content of the document.
Corresponds to the JSON property content
209 210 211 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 209 def content @content end |
#create_time ⇒ String
Output only. The timestamp of the original external publication of the
document.
Corresponds to the JSON property createTime
215 216 217 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 215 def create_time @create_time end |
#ingest_time ⇒ String
Output only. Time when GTI received the intel.
Corresponds to the JSON property ingestTime
220 221 222 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 220 def ingest_time @ingest_time end |
#language_code ⇒ String
Output only. The language code of the document.
Corresponds to the JSON property languageCode
225 226 227 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 225 def language_code @language_code end |
#name ⇒ String
Identifier. Server generated name for the alert document. format is projects/
project/alerts/alert/documents/document
Corresponds to the JSON property name
231 232 233 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 231 def name @name end |
#source ⇒ String
Output only. Source of the intel item, e.g. DarkMarket.
Corresponds to the JSON property source
236 237 238 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 236 def source @source end |
#source_update_time ⇒ String
Output only. Time when the intel was last updated by the source.
Corresponds to the JSON property sourceUpdateTime
241 242 243 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 241 def source_update_time @source_update_time end |
#source_uri ⇒ String
Output only. URI of the intel item from the source.
Corresponds to the JSON property sourceUri
246 247 248 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 246 def source_uri @source_uri end |
#title ⇒ String
Output only. The title of the document, if available.
Corresponds to the JSON property title
251 252 253 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 251 def title @title end |
#translation ⇒ Google::Apis::ThreatintelligenceV1beta::AlertDocumentTranslation
The translation of an alert document.
Corresponds to the JSON property translation
256 257 258 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 256 def translation @translation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 263 def update!(**args) @ai_summary = args[:ai_summary] if args.key?(:ai_summary) @author = args[:author] if args.key?(:author) @collection_time = args[:collection_time] if args.key?(:collection_time) @content = args[:content] if args.key?(:content) @create_time = args[:create_time] if args.key?(:create_time) @ingest_time = args[:ingest_time] if args.key?(:ingest_time) @language_code = args[:language_code] if args.key?(:language_code) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @source_update_time = args[:source_update_time] if args.key?(:source_update_time) @source_uri = args[:source_uri] if args.key?(:source_uri) @title = args[:title] if args.key?(:title) @translation = args[:translation] if args.key?(:translation) end |