Class: Google::Apis::ThreatintelligenceV1beta::Audit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

Tracks basic CRUD facts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Audit

Returns a new instance of Audit.



355
356
357
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 355

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time of creation. Corresponds to the JSON property createTime

Returns:

  • (String)


337
338
339
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 337

def create_time
  @create_time
end

#creatorString

Output only. Agent that created or updated the record, could be a UserId or a JobId. Corresponds to the JSON property creator

Returns:

  • (String)


343
344
345
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 343

def creator
  @creator
end

#update_timeString

Output only. Time of creation or last update. Corresponds to the JSON property updateTime

Returns:

  • (String)


348
349
350
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 348

def update_time
  @update_time
end

#updaterString

Output only. Agent that last updated the record, could be a UserId or a JobId. Corresponds to the JSON property updater

Returns:

  • (String)


353
354
355
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 353

def updater
  @updater
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



360
361
362
363
364
365
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 360

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator = args[:creator] if args.key?(:creator)
  @update_time = args[:update_time] if args.key?(:update_time)
  @updater = args[:updater] if args.key?(:updater)
end