Class: Google::Apis::ThreatintelligenceV1beta::ConfigurationDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

Wrapper class that contains the union struct for all the various configuration detail specific classes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigurationDetail

Returns a new instance of ConfigurationDetail.



467
468
469
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_threat_scenarioGoogle::Apis::ThreatintelligenceV1beta::CustomThreatScenarioConfig

CustomThreatScenarioConfig represents a user-defined threat scenario configuration. Corresponds to the JSON property customThreatScenario



449
450
451
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 449

def custom_threat_scenario
  @custom_threat_scenario
end

#customer_profileGoogle::Apis::ThreatintelligenceV1beta::CustomerProfileConfig

CustomerProfileConfig is the configuration for the customer profile. Corresponds to the JSON property customerProfile



454
455
456
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 454

def customer_profile
  @customer_profile
end

#detail_typeString

Output only. Name of the detail type. Will be set by the server during creation to the name of the field that is set in the detail union. Corresponds to the JSON property detailType

Returns:

  • (String)


460
461
462
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 460

def detail_type
  @detail_type
end

#technology_watchlistGoogle::Apis::ThreatintelligenceV1beta::TechnologyWatchListConfig

TechnologyWatchListConfig is the configuration for the technology watchlist. Corresponds to the JSON property technologyWatchlist



465
466
467
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 465

def technology_watchlist
  @technology_watchlist
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



472
473
474
475
476
477
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 472

def update!(**args)
  @custom_threat_scenario = args[:custom_threat_scenario] if args.key?(:custom_threat_scenario)
  @customer_profile = args[:customer_profile] if args.key?(:customer_profile)
  @detail_type = args[:detail_type] if args.key?(:detail_type)
  @technology_watchlist = args[:technology_watchlist] if args.key?(:technology_watchlist)
end