Class: Google::Apis::ThreatintelligenceV1beta::ConfigurationRevision
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::ConfigurationRevision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
A ConfigurationRevision is a snapshot of a Configuration at a point in time. It is immutable.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#snapshot ⇒ Google::Apis::ThreatintelligenceV1beta::Configuration
A configuration represents a behavior an engine should follow when producing new findings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigurationRevision
constructor
A new instance of ConfigurationRevision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigurationRevision
Returns a new instance of ConfigurationRevision.
495 496 497 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 495 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the Revision was created
Corresponds to the JSON property createTime
481 482 483 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 481 def create_time @create_time end |
#name ⇒ String
Identifier. The name of the ConfigurationRevision Format: projects//
configurations//revisions/
Corresponds to the JSON property name
487 488 489 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 487 def name @name end |
#snapshot ⇒ Google::Apis::ThreatintelligenceV1beta::Configuration
A configuration represents a behavior an engine should follow when producing
new findings.
Corresponds to the JSON property snapshot
493 494 495 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 493 def snapshot @snapshot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
500 501 502 503 504 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 500 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @snapshot = args[:snapshot] if args.key?(:snapshot) end |