Class: Google::Apis::ThreatintelligenceV1beta::Evidence
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::Evidence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
Details the evidence used to determine the relevance verdict.
Instance Attribute Summary collapse
-
#common_themes ⇒ Array<String>
A list of semantic themes or concepts found to be common, related, or aligned between the sources, supporting the verdict.
-
#distinct_themes ⇒ Array<String>
A list of semantic themes or descriptions unique to one source or semantically distant.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Evidence
constructor
A new instance of Evidence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Evidence
Returns a new instance of Evidence.
1139 1140 1141 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1139 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common_themes ⇒ Array<String>
A list of semantic themes or concepts found to be common, related, or aligned
between the sources, supporting the verdict.
Corresponds to the JSON property commonThemes
1131 1132 1133 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1131 def common_themes @common_themes end |
#distinct_themes ⇒ Array<String>
A list of semantic themes or descriptions unique to one source or semantically
distant.
Corresponds to the JSON property distinctThemes
1137 1138 1139 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1137 def distinct_themes @distinct_themes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1144 1145 1146 1147 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1144 def update!(**args) @common_themes = args[:common_themes] if args.key?(:common_themes) @distinct_themes = args[:distinct_themes] if args.key?(:distinct_themes) end |