Class: Google::Apis::ThreatintelligenceV1beta::Finding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

A ‘stateless’ and a point in time event that a check produced a result of interest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Finding

Returns a new instance of Finding.



1289
1290
1291
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_summaryString

Optional. AI summary of the finding. Corresponds to the JSON property aiSummary

Returns:

  • (String)


1227
1228
1229
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1227

def ai_summary
  @ai_summary
end

#alertString

Optional. Name of the alert that this finding is bound to. Corresponds to the JSON property alert

Returns:

  • (String)


1232
1233
1234
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1232

def alert
  @alert
end

#auditGoogle::Apis::ThreatintelligenceV1beta::Audit

Tracks basic CRUD facts. Corresponds to the JSON property audit



1237
1238
1239
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1237

def audit
  @audit
end

#configurationsArray<String>

Optional. Configuration names that are bound to this finding. Corresponds to the JSON property configurations

Returns:

  • (Array<String>)


1242
1243
1244
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1242

def configurations
  @configurations
end

#detailGoogle::Apis::ThreatintelligenceV1beta::FindingDetail

Wrapper class that contains the union struct for all the various findings detail specific classes. Corresponds to the JSON property detail



1248
1249
1250
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1248

def detail
  @detail
end

#display_nameString

Required. A short descriptive title for the finding <= 250 chars. EX: "Actor ' baddy' offering $1000 for credentials of 'goodguy'". Corresponds to the JSON property displayName

Returns:

  • (String)


1254
1255
1256
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1254

def display_name
  @display_name
end

#nameString

Identifier. Server generated name for the finding (leave clear during creation) . Format: projects/project/findings/finding Corresponds to the JSON property name

Returns:

  • (String)


1260
1261
1262
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1260

def name
  @name
end

#providerString

Required. Logical source of this finding (name of the sub-engine). Corresponds to the JSON property provider

Returns:

  • (String)


1265
1266
1267
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1265

def provider
  @provider
end

#relevance_analysisGoogle::Apis::ThreatintelligenceV1beta::RelevanceAnalysis

Structured relevance analysis for a threat. Corresponds to the JSON property relevanceAnalysis



1270
1271
1272
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1270

def relevance_analysis
  @relevance_analysis
end

#reoccurrence_timesArray<String>

Output only. When identical finding (same labels and same details) has re- occurred. Corresponds to the JSON property reoccurrenceTimes

Returns:

  • (Array<String>)


1276
1277
1278
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1276

def reoccurrence_times
  @reoccurrence_times
end

#severityFloat

Optional. Deprecated: Use the severity_analysis field instead. Base severity score from the finding source. Corresponds to the JSON property severity

Returns:

  • (Float)


1282
1283
1284
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1282

def severity
  @severity
end

#severity_analysisGoogle::Apis::ThreatintelligenceV1beta::SeverityAnalysis

Structured severity analysis for a threat. Corresponds to the JSON property severityAnalysis



1287
1288
1289
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1287

def severity_analysis
  @severity_analysis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1294

def update!(**args)
  @ai_summary = args[:ai_summary] if args.key?(:ai_summary)
  @alert = args[:alert] if args.key?(:alert)
  @audit = args[:audit] if args.key?(:audit)
  @configurations = args[:configurations] if args.key?(:configurations)
  @detail = args[:detail] if args.key?(:detail)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @provider = args[:provider] if args.key?(:provider)
  @relevance_analysis = args[:relevance_analysis] if args.key?(:relevance_analysis)
  @reoccurrence_times = args[:reoccurrence_times] if args.key?(:reoccurrence_times)
  @severity = args[:severity] if args.key?(:severity)
  @severity_analysis = args[:severity_analysis] if args.key?(:severity_analysis)
end