Class: Google::Apis::ThreatintelligenceV1beta::GenerateOrgProfileConfigurationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

Request message for GenerateOrgProfileConfiguration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateOrgProfileConfigurationRequest

Returns a new instance of GenerateOrgProfileConfigurationRequest.



1381
1382
1383
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Required. The display name of the organization to generate the profile for. Corresponds to the JSON property displayName

Returns:

  • (String)


1374
1375
1376
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1374

def display_name
  @display_name
end

#domainString

Required. The domain of the organization to generate the profile for. Corresponds to the JSON property domain

Returns:

  • (String)


1379
1380
1381
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1379

def domain
  @domain
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1386
1387
1388
1389
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1386

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @domain = args[:domain] if args.key?(:domain)
end