Class: Google::Apis::ThreatintelligenceV1beta::InitialAccessBrokerFindingDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

A detail object for an Initial Access Broker (IAB) finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InitialAccessBrokerFindingDetail

Returns a new instance of InitialAccessBrokerFindingDetail.



1461
1462
1463
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_idString

Required. The unique identifier of the document that triggered the IAB finding. This ID can be used to retrieve the content of the document for further analysis. Corresponds to the JSON property documentId

Returns:

  • (String)


1446
1447
1448
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1446

def document_id
  @document_id
end

#match_scoreFloat

Required. Reference to the match score of the IAB finding. This is a float value between 0 and 1 calculated by the matching engine based on the similarity of the document and the user provided configurations. Corresponds to the JSON property matchScore

Returns:

  • (Float)


1453
1454
1455
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1453

def match_score
  @match_score
end

#severityString

Required. The severity of the IAB finding. This indicates the potential impact of the threat. Corresponds to the JSON property severity

Returns:

  • (String)


1459
1460
1461
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1459

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1466
1467
1468
1469
1470
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1466

def update!(**args)
  @document_id = args[:document_id] if args.key?(:document_id)
  @match_score = args[:match_score] if args.key?(:match_score)
  @severity = args[:severity] if args.key?(:severity)
end