Class: Google::Apis::ThreatintelligenceV1beta::LegacyMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

Legacy metadata associated with this scenario/monitor.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LegacyMetadata

Returns a new instance of LegacyMetadata.



1623
1624
1625
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_enabledBoolean Also known as: aggregation_enabled?

Optional. Whether aggregation is enabled for alerts from this monitor. Corresponds to the JSON property aggregationEnabled

Returns:

  • (Boolean)


1543
1544
1545
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1543

def aggregation_enabled
  @aggregation_enabled
end

#aggregation_similarityFloat

Optional. Similarity threshold for aggregation. Corresponds to the JSON property aggregationSimilarity

Returns:

  • (Float)


1549
1550
1551
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1549

def aggregation_similarity
  @aggregation_similarity
end

#condition_versionFixnum

Optional. Version of the condition schema. Corresponds to the JSON property conditionVersion

Returns:

  • (Fixnum)


1554
1555
1556
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1554

def condition_version
  @condition_version
end

#creator_user_idString

Optional. User ID who created the monitor. Corresponds to the JSON property creatorUserId

Returns:

  • (String)


1559
1560
1561
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1559

def creator_user_id
  @creator_user_id
end

#descriptionString

Optional. Description of the legacy monitor. Corresponds to the JSON property description

Returns:

  • (String)


1564
1565
1566
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1564

def description
  @description
end

#disabled_codeString

Optional. Code indicating why the monitor is disabled (if applicable). Corresponds to the JSON property disabledCode

Returns:

  • (String)


1569
1570
1571
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1569

def disabled_code
  @disabled_code
end

#disabled_reasonString

Optional. Reason why the monitor is disabled (if applicable). Corresponds to the JSON property disabledReason

Returns:

  • (String)


1574
1575
1576
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1574

def disabled_reason
  @disabled_reason
end

#display_nameString

Optional. Name of the legacy monitor. Corresponds to the JSON property displayName

Returns:

  • (String)


1579
1580
1581
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1579

def display_name
  @display_name
end

#email_notification_enabledBoolean Also known as: email_notification_enabled?

Optional. Whether email notifications are enabled. Corresponds to the JSON property emailNotificationEnabled

Returns:

  • (Boolean)


1584
1585
1586
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1584

def email_notification_enabled
  @email_notification_enabled
end

#email_notification_immediateBoolean Also known as: email_notification_immediate?

Optional. Whether email notifications are intermediate/immediate. Corresponds to the JSON property emailNotificationImmediate

Returns:

  • (Boolean)


1590
1591
1592
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1590

def email_notification_immediate
  @email_notification_immediate
end

#legacy_monitor_idString

Optional. Unique identifier of the legacy monitor. Corresponds to the JSON property legacyMonitorId

Returns:

  • (String)


1596
1597
1598
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1596

def legacy_monitor_id
  @legacy_monitor_id
end

#stale_timeString

Optional. Time the legacy monitor was considered stale. Corresponds to the JSON property staleTime

Returns:

  • (String)


1601
1602
1603
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1601

def stale_time
  @stale_time
end

#template_idString

Optional. ID of the template this monitor was created from. Corresponds to the JSON property templateId

Returns:

  • (String)


1606
1607
1608
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1606

def template_id
  @template_id
end

#tenant_idString

Optional. ID of the tenant owning the monitor. Corresponds to the JSON property tenantId

Returns:

  • (String)


1611
1612
1613
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1611

def tenant_id
  @tenant_id
end

#updater_user_idString

Optional. User ID who last updated the monitor. Corresponds to the JSON property updaterUserId

Returns:

  • (String)


1616
1617
1618
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1616

def updater_user_id
  @updater_user_id
end

#versionFixnum

Optional. Version of the monitor configuration. Corresponds to the JSON property version

Returns:

  • (Fixnum)


1621
1622
1623
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1621

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1628

def update!(**args)
  @aggregation_enabled = args[:aggregation_enabled] if args.key?(:aggregation_enabled)
  @aggregation_similarity = args[:aggregation_similarity] if args.key?(:aggregation_similarity)
  @condition_version = args[:condition_version] if args.key?(:condition_version)
  @creator_user_id = args[:creator_user_id] if args.key?(:creator_user_id)
  @description = args[:description] if args.key?(:description)
  @disabled_code = args[:disabled_code] if args.key?(:disabled_code)
  @disabled_reason = args[:disabled_reason] if args.key?(:disabled_reason)
  @display_name = args[:display_name] if args.key?(:display_name)
  @email_notification_enabled = args[:email_notification_enabled] if args.key?(:email_notification_enabled)
  @email_notification_immediate = args[:email_notification_immediate] if args.key?(:email_notification_immediate)
  @legacy_monitor_id = args[:legacy_monitor_id] if args.key?(:legacy_monitor_id)
  @stale_time = args[:stale_time] if args.key?(:stale_time)
  @template_id = args[:template_id] if args.key?(:template_id)
  @tenant_id = args[:tenant_id] if args.key?(:tenant_id)
  @updater_user_id = args[:updater_user_id] if args.key?(:updater_user_id)
  @version = args[:version] if args.key?(:version)
end