Class: Google::Apis::ThreatintelligenceV1beta::PriorityAnalysis
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::PriorityAnalysis
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
Structured priority analysis for a threat.
Instance Attribute Summary collapse
-
#confidence ⇒ String
The level of confidence in the given verdict.
-
#priority_level ⇒ String
The level of Priority.
-
#reasoning ⇒ String
Human-readable explanation from the model, detailing why a particular result is considered to have a certain priority.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PriorityAnalysis
constructor
A new instance of PriorityAnalysis.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PriorityAnalysis
Returns a new instance of PriorityAnalysis.
1812 1813 1814 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1812 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ String
The level of confidence in the given verdict.
Corresponds to the JSON property confidence
1799 1800 1801 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1799 def confidence @confidence end |
#priority_level ⇒ String
The level of Priority.
Corresponds to the JSON property priorityLevel
1804 1805 1806 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1804 def priority_level @priority_level end |
#reasoning ⇒ String
Human-readable explanation from the model, detailing why a particular result
is considered to have a certain priority.
Corresponds to the JSON property reasoning
1810 1811 1812 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1810 def reasoning @reasoning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1817 1818 1819 1820 1821 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1817 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @priority_level = args[:priority_level] if args.key?(:priority_level) @reasoning = args[:reasoning] if args.key?(:reasoning) end |