Class: Google::Apis::ThreatintelligenceV1beta::RelevanceAnalysis
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::RelevanceAnalysis
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
Structured relevance analysis for a threat.
Instance Attribute Summary collapse
-
#confidence ⇒ String
The level of confidence in the given verdict.
-
#evidence ⇒ Google::Apis::ThreatintelligenceV1beta::Evidence
Details the evidence used to determine the relevance verdict.
-
#reasoning ⇒ String
Human-readable explanation from the matcher, detailing why a particular result is considered relevant or not relevant.
-
#relevance_level ⇒ String
The level of relevance.
-
#relevant ⇒ Boolean
(also: #relevant?)
Indicates whether the threat is considered relevant.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RelevanceAnalysis
constructor
A new instance of RelevanceAnalysis.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RelevanceAnalysis
Returns a new instance of RelevanceAnalysis.
2084 2085 2086 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 2084 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ String
The level of confidence in the given verdict.
Corresponds to the JSON property confidence
2060 2061 2062 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 2060 def confidence @confidence end |
#evidence ⇒ Google::Apis::ThreatintelligenceV1beta::Evidence
Details the evidence used to determine the relevance verdict.
Corresponds to the JSON property evidence
2065 2066 2067 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 2065 def evidence @evidence end |
#reasoning ⇒ String
Human-readable explanation from the matcher, detailing why a particular result
is considered relevant or not relevant.
Corresponds to the JSON property reasoning
2071 2072 2073 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 2071 def reasoning @reasoning end |
#relevance_level ⇒ String
The level of relevance.
Corresponds to the JSON property relevanceLevel
2076 2077 2078 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 2076 def relevance_level @relevance_level end |
#relevant ⇒ Boolean Also known as: relevant?
Indicates whether the threat is considered relevant.
Corresponds to the JSON property relevant
2081 2082 2083 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 2081 def relevant @relevant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 2089 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @evidence = args[:evidence] if args.key?(:evidence) @reasoning = args[:reasoning] if args.key?(:reasoning) @relevance_level = args[:relevance_level] if args.key?(:relevance_level) @relevant = args[:relevant] if args.key?(:relevant) end |