Class: Google::Apis::ThreatintelligenceV1beta::SeverityAnalysis
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::SeverityAnalysis
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
Structured severity analysis for a threat.
Instance Attribute Summary collapse
-
#confidence ⇒ String
The level of confidence in the given verdict.
-
#reasoning ⇒ String
Human-readable explanation from the model, detailing why a particular result is considered to have a certain severity.
-
#severity_level ⇒ String
The level of severity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SeverityAnalysis
constructor
A new instance of SeverityAnalysis.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SeverityAnalysis
Returns a new instance of SeverityAnalysis.
2143 2144 2145 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 2143 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ String
The level of confidence in the given verdict.
Corresponds to the JSON property confidence
2130 2131 2132 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 2130 def confidence @confidence end |
#reasoning ⇒ String
Human-readable explanation from the model, detailing why a particular result
is considered to have a certain severity.
Corresponds to the JSON property reasoning
2136 2137 2138 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 2136 def reasoning @reasoning end |
#severity_level ⇒ String
The level of severity.
Corresponds to the JSON property severityLevel
2141 2142 2143 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 2141 def severity_level @severity_level end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2148 2149 2150 2151 2152 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 2148 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @reasoning = args[:reasoning] if args.key?(:reasoning) @severity_level = args[:severity_level] if args.key?(:severity_level) end |