Module: Google::Apis::ThreatintelligenceV1beta
- Defined in:
- lib/google/apis/threatintelligence_v1beta.rb,
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/service.rb,
lib/google/apis/threatintelligence_v1beta/gem_version.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
Threat Intelligence API
threatintelligence.googleapis.com API.
Defined Under Namespace
Classes: Alert, AlertDetail, AlertDocument, AlertDocumentTranslation, Audit, Configuration, ConfigurationDetail, ConfigurationRevision, CustomerProfileCitation, CustomerProfileCitedString, CustomerProfileCompany, CustomerProfileConfig, CustomerProfileContactInfo, CustomerProfileIndustry, CustomerProfileLocation, CustomerProfilePerson, CustomerProfileProduct, CustomerProfileSecurityConsiderations, CustomerProfileSummary, CustomerProfileWebPresence, DataLeakAlertDetail, DataLeakFindingDetail, EnumerateAlertFacetsResponse, Evidence, Facet, FacetCount, Finding, FindingDetail, GenerateOrgProfileConfigurationRequest, InitialAccessBrokerAlertDetail, InitialAccessBrokerFindingDetail, InsiderThreatAlertDetail, InsiderThreatFindingDetail, ListAlertsResponse, ListConfigurationRevisionsResponse, ListConfigurationsResponse, ListFindingsResponse, MarkAlertAsBenignRequest, MarkAlertAsDuplicateRequest, MarkAlertAsEscalatedRequest, MarkAlertAsFalsePositiveRequest, MarkAlertAsNotActionableRequest, MarkAlertAsReadRequest, MarkAlertAsResolvedRequest, MarkAlertAsTrackedExternallyRequest, MarkAlertAsTriagedRequest, Operation, PriorityAnalysis, RelevanceAnalysis, SearchFindingsResponse, SeverityAnalysis, Status, ThreatIntelligenceServiceService, UpsertConfigurationResponse
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-threatintelligence_v1beta gem
"0.7.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20260412"- VERSION =
Version of the Threat Intelligence API this client connects to. This is NOT the gem version.
'V1beta'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'