Class: Google::Apis::ThreatintelligenceV1beta::AlertDocument

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

A document that is associated with an alert.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AlertDocument

Returns a new instance of AlertDocument.



252
253
254
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 252

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_summaryString

Output only. AI summary of the finding. Corresponds to the JSON property aiSummary

Returns:

  • (String)


188
189
190
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 188

def ai_summary
  @ai_summary
end

#authorString

Output only. The author of the document. Corresponds to the JSON property author

Returns:

  • (String)


193
194
195
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 193

def author
  @author
end

#collection_timeString

Output only. Time when the origin source collected the intel. Corresponds to the JSON property collectionTime

Returns:

  • (String)


198
199
200
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 198

def collection_time
  @collection_time
end

#contentString

Output only. The content of the document. Corresponds to the JSON property content

Returns:

  • (String)


203
204
205
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 203

def content
  @content
end

#create_timeString

Output only. The timestamp of the original external publication of the document. Corresponds to the JSON property createTime

Returns:

  • (String)


209
210
211
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 209

def create_time
  @create_time
end

#ingest_timeString

Output only. Time when GTI received the intel. Corresponds to the JSON property ingestTime

Returns:

  • (String)


214
215
216
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 214

def ingest_time
  @ingest_time
end

#language_codeString

Output only. The language code of the document. Corresponds to the JSON property languageCode

Returns:

  • (String)


219
220
221
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 219

def language_code
  @language_code
end

#nameString

Identifier. Server generated name for the alert document. format is projects/ project/alerts/alert/documents/document Corresponds to the JSON property name

Returns:

  • (String)


225
226
227
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 225

def name
  @name
end

#sourceString

Output only. Source of the intel item, e.g. DarkMarket. Corresponds to the JSON property source

Returns:

  • (String)


230
231
232
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 230

def source
  @source
end

#source_update_timeString

Output only. Time when the intel was last updated by the source. Corresponds to the JSON property sourceUpdateTime

Returns:

  • (String)


235
236
237
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 235

def source_update_time
  @source_update_time
end

#source_uriString

Output only. URI of the intel item from the source. Corresponds to the JSON property sourceUri

Returns:

  • (String)


240
241
242
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 240

def source_uri
  @source_uri
end

#titleString

Output only. The title of the document, if available. Corresponds to the JSON property title

Returns:

  • (String)


245
246
247
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 245

def title
  @title
end

#translationGoogle::Apis::ThreatintelligenceV1beta::AlertDocumentTranslation

The translation of an alert document. Corresponds to the JSON property translation



250
251
252
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 250

def translation
  @translation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 257

def update!(**args)
  @ai_summary = args[:ai_summary] if args.key?(:ai_summary)
  @author = args[:author] if args.key?(:author)
  @collection_time = args[:collection_time] if args.key?(:collection_time)
  @content = args[:content] if args.key?(:content)
  @create_time = args[:create_time] if args.key?(:create_time)
  @ingest_time = args[:ingest_time] if args.key?(:ingest_time)
  @language_code = args[:language_code] if args.key?(:language_code)
  @name = args[:name] if args.key?(:name)
  @source = args[:source] if args.key?(:source)
  @source_update_time = args[:source_update_time] if args.key?(:source_update_time)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @title = args[:title] if args.key?(:title)
  @translation = args[:translation] if args.key?(:translation)
end