Class: Google::Apis::ThreatintelligenceV1beta::Audit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

Tracks basic CRUD facts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Audit

Returns a new instance of Audit.



323
324
325
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 323

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time of creation. Corresponds to the JSON property createTime

Returns:

  • (String)


305
306
307
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 305

def create_time
  @create_time
end

#creatorString

Output only. Agent that created or updated the record, could be a UserId or a JobId. Corresponds to the JSON property creator

Returns:

  • (String)


311
312
313
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 311

def creator
  @creator
end

#update_timeString

Output only. Time of creation or last update. Corresponds to the JSON property updateTime

Returns:

  • (String)


316
317
318
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 316

def update_time
  @update_time
end

#updaterString

Output only. Agent that last updated the record, could be a UserId or a JobId. Corresponds to the JSON property updater

Returns:

  • (String)


321
322
323
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 321

def updater
  @updater
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



328
329
330
331
332
333
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 328

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator = args[:creator] if args.key?(:creator)
  @update_time = args[:update_time] if args.key?(:update_time)
  @updater = args[:updater] if args.key?(:updater)
end