Class: Google::Apis::ThreatintelligenceV1beta::Configuration
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::Configuration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
A configuration represents a behavior an engine should follow when producing new findings.
Instance Attribute Summary collapse
-
#audit ⇒ Google::Apis::ThreatintelligenceV1beta::Audit
Tracks basic CRUD facts.
-
#description ⇒ String
Optional.
-
#detail ⇒ Google::Apis::ThreatintelligenceV1beta::ConfigurationDetail
Wrapper class that contains the union struct for all the various configuration detail specific classes.
-
#display_name ⇒ String
Output only.
-
#etag ⇒ String
If included when updating a configuration, this should be set to the current etag of the configuration.
-
#name ⇒ String
Identifier.
-
#provider ⇒ String
Required.
-
#state ⇒ String
Optional.
-
#version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Configuration
constructor
A new instance of Configuration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Configuration
Returns a new instance of Configuration.
422 423 424 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 422 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audit ⇒ Google::Apis::ThreatintelligenceV1beta::Audit
Tracks basic CRUD facts.
Corresponds to the JSON property audit
376 377 378 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 376 def audit @audit end |
#description ⇒ String
Optional. A description of the configuration.
Corresponds to the JSON property description
381 382 383 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 381 def description @description end |
#detail ⇒ Google::Apis::ThreatintelligenceV1beta::ConfigurationDetail
Wrapper class that contains the union struct for all the various configuration
detail specific classes.
Corresponds to the JSON property detail
387 388 389 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 387 def detail @detail end |
#display_name ⇒ String
Output only. Human readable name for the configuration.
Corresponds to the JSON property displayName
392 393 394 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 392 def display_name @display_name end |
#etag ⇒ String
If included when updating a configuration, this should be set to the current
etag of the configuration. If the etags do not match, the update will be
rejected and an ABORTED error will be returned.
Corresponds to the JSON property etag
399 400 401 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 399 def etag @etag end |
#name ⇒ String
Identifier. Server generated name for the configuration. format is projects/
project/configurations/configuration
Corresponds to the JSON property name
405 406 407 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 405 def name @name end |
#provider ⇒ String
Required. Name of the service that provides the configuration.
Corresponds to the JSON property provider
410 411 412 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 410 def provider @provider end |
#state ⇒ String
Optional. State of the configuration.
Corresponds to the JSON property state
415 416 417 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 415 def state @state end |
#version ⇒ String
Optional. A user-manipulatable version. Does not adhere to a specific format
Corresponds to the JSON property version
420 421 422 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 420 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 427 def update!(**args) @audit = args[:audit] if args.key?(:audit) @description = args[:description] if args.key?(:description) @detail = args[:detail] if args.key?(:detail) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @state = args[:state] if args.key?(:state) @version = args[:version] if args.key?(:version) end |