Class: Google::Apis::ThreatintelligenceV1beta::Configuration
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::Configuration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
A configuration represents a behavior an engine should follow when producing new findings.
Instance Attribute Summary collapse
-
#audit ⇒ Google::Apis::ThreatintelligenceV1beta::Audit
Tracks basic CRUD facts.
-
#description ⇒ String
Optional.
-
#detail ⇒ Google::Apis::ThreatintelligenceV1beta::ConfigurationDetail
Wrapper class that contains the union struct for all the various configuration detail specific classes.
-
#display_name ⇒ String
Output only.
-
#etag ⇒ String
If included when updating a configuration, this should be set to the current etag of the configuration.
-
#name ⇒ String
Identifier.
-
#provider ⇒ String
Required.
-
#state ⇒ String
Optional.
-
#version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Configuration
constructor
A new instance of Configuration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Configuration
Returns a new instance of Configuration.
391 392 393 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 391 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audit ⇒ Google::Apis::ThreatintelligenceV1beta::Audit
Tracks basic CRUD facts.
Corresponds to the JSON property audit
345 346 347 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 345 def audit @audit end |
#description ⇒ String
Optional. A description of the configuration.
Corresponds to the JSON property description
350 351 352 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 350 def description @description end |
#detail ⇒ Google::Apis::ThreatintelligenceV1beta::ConfigurationDetail
Wrapper class that contains the union struct for all the various configuration
detail specific classes.
Corresponds to the JSON property detail
356 357 358 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 356 def detail @detail end |
#display_name ⇒ String
Output only. Human readable name for the configuration.
Corresponds to the JSON property displayName
361 362 363 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 361 def display_name @display_name end |
#etag ⇒ String
If included when updating a configuration, this should be set to the current
etag of the configuration. If the etags do not match, the update will be
rejected and an ABORTED error will be returned.
Corresponds to the JSON property etag
368 369 370 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 368 def etag @etag end |
#name ⇒ String
Identifier. Server generated name for the configuration. format is projects/
project/configurations/configuration
Corresponds to the JSON property name
374 375 376 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 374 def name @name end |
#provider ⇒ String
Required. Name of the service that provides the configuration.
Corresponds to the JSON property provider
379 380 381 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 379 def provider @provider end |
#state ⇒ String
Optional. State of the configuration.
Corresponds to the JSON property state
384 385 386 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 384 def state @state end |
#version ⇒ String
Optional. A user-manipulatable version. Does not adhere to a specific format
Corresponds to the JSON property version
389 390 391 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 389 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 396 def update!(**args) @audit = args[:audit] if args.key?(:audit) @description = args[:description] if args.key?(:description) @detail = args[:detail] if args.key?(:detail) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @state = args[:state] if args.key?(:state) @version = args[:version] if args.key?(:version) end |