Class: Google::Apis::ThreatintelligenceV1beta::Configuration
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::Configuration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
A configuration represents a behavior an engine should follow when producing new findings.
Instance Attribute Summary collapse
-
#audit ⇒ Google::Apis::ThreatintelligenceV1beta::Audit
Tracks basic CRUD facts.
-
#description ⇒ String
Optional.
-
#detail ⇒ Google::Apis::ThreatintelligenceV1beta::ConfigurationDetail
Wrapper class that contains the union struct for all the various configuration detail specific classes.
-
#display_name ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#provider ⇒ String
Required.
-
#state ⇒ String
Optional.
-
#version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Configuration
constructor
A new instance of Configuration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Configuration
Returns a new instance of Configuration.
384 385 386 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 384 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audit ⇒ Google::Apis::ThreatintelligenceV1beta::Audit
Tracks basic CRUD facts.
Corresponds to the JSON property audit
345 346 347 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 345 def audit @audit end |
#description ⇒ String
Optional. A description of the configuration.
Corresponds to the JSON property description
350 351 352 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 350 def description @description end |
#detail ⇒ Google::Apis::ThreatintelligenceV1beta::ConfigurationDetail
Wrapper class that contains the union struct for all the various configuration
detail specific classes.
Corresponds to the JSON property detail
356 357 358 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 356 def detail @detail end |
#display_name ⇒ String
Output only. Human readable name for the configuration.
Corresponds to the JSON property displayName
361 362 363 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 361 def display_name @display_name end |
#name ⇒ String
Identifier. Server generated name for the configuration. format is projects/
project/configurations/configuration
Corresponds to the JSON property name
367 368 369 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 367 def name @name end |
#provider ⇒ String
Required. Name of the service that provides the configuration.
Corresponds to the JSON property provider
372 373 374 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 372 def provider @provider end |
#state ⇒ String
Optional. State of the configuration.
Corresponds to the JSON property state
377 378 379 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 377 def state @state end |
#version ⇒ String
Optional. A user-manipulatable version. Does not adhere to a specific format
Corresponds to the JSON property version
382 383 384 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 382 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
389 390 391 392 393 394 395 396 397 398 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 389 def update!(**args) @audit = args[:audit] if args.key?(:audit) @description = args[:description] if args.key?(:description) @detail = args[:detail] if args.key?(:detail) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @state = args[:state] if args.key?(:state) @version = args[:version] if args.key?(:version) end |