Class: Google::Apis::ThreatintelligenceV1beta::Configuration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

A configuration represents a behavior an engine should follow when producing new findings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Configuration

Returns a new instance of Configuration.



383
384
385
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 383

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auditGoogle::Apis::ThreatintelligenceV1beta::Audit

Tracks basic CRUD facts. Corresponds to the JSON property audit



344
345
346
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 344

def audit
  @audit
end

#descriptionString

Optional. A description of the configuration. Corresponds to the JSON property description

Returns:

  • (String)


349
350
351
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 349

def description
  @description
end

#detailGoogle::Apis::ThreatintelligenceV1beta::ConfigurationDetail

Wrapper class that contains the union struct for all the various configuration detail specific classes. Corresponds to the JSON property detail



355
356
357
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 355

def detail
  @detail
end

#display_nameString

Output only. Human readable name for the configuration. Corresponds to the JSON property displayName

Returns:

  • (String)


360
361
362
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 360

def display_name
  @display_name
end

#nameString

Identifier. Server generated name for the configuration. format is projects/ project/configurations/configuration Corresponds to the JSON property name

Returns:

  • (String)


366
367
368
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 366

def name
  @name
end

#providerString

Required. Name of the service that provides the configuration. Corresponds to the JSON property provider

Returns:

  • (String)


371
372
373
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 371

def provider
  @provider
end

#stateString

Optional. State of the configuration. Corresponds to the JSON property state

Returns:

  • (String)


376
377
378
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 376

def state
  @state
end

#versionString

Optional. A user-manipulatable version. Does not adhere to a specific format Corresponds to the JSON property version

Returns:

  • (String)


381
382
383
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 381

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



388
389
390
391
392
393
394
395
396
397
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 388

def update!(**args)
  @audit = args[:audit] if args.key?(:audit)
  @description = args[:description] if args.key?(:description)
  @detail = args[:detail] if args.key?(:detail)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @provider = args[:provider] if args.key?(:provider)
  @state = args[:state] if args.key?(:state)
  @version = args[:version] if args.key?(:version)
end