Class: Google::Apis::ThreatintelligenceV1beta::ConfigurationDetail
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::ConfigurationDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
Wrapper class that contains the union struct for all the various configuration detail specific classes.
Instance Attribute Summary collapse
-
#customer_profile ⇒ Google::Apis::ThreatintelligenceV1beta::CustomerProfileConfig
CustomerProfileConfig is the configuration for the customer profile.
-
#detail_type ⇒ String
Output only.
-
#technology_watchlist ⇒ Google::Apis::ThreatintelligenceV1beta::TechnologyWatchListConfig
TechnologyWatchListConfig is the configuration for the technology watchlist.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigurationDetail
constructor
A new instance of ConfigurationDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigurationDetail
Returns a new instance of ConfigurationDetail.
461 462 463 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer_profile ⇒ Google::Apis::ThreatintelligenceV1beta::CustomerProfileConfig
CustomerProfileConfig is the configuration for the customer profile.
Corresponds to the JSON property customerProfile
448 449 450 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 448 def customer_profile @customer_profile end |
#detail_type ⇒ String
Output only. Name of the detail type. Will be set by the server during
creation to the name of the field that is set in the detail union.
Corresponds to the JSON property detailType
454 455 456 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 454 def detail_type @detail_type end |
#technology_watchlist ⇒ Google::Apis::ThreatintelligenceV1beta::TechnologyWatchListConfig
TechnologyWatchListConfig is the configuration for the technology watchlist.
Corresponds to the JSON property technologyWatchlist
459 460 461 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 459 def technology_watchlist @technology_watchlist end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
466 467 468 469 470 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 466 def update!(**args) @customer_profile = args[:customer_profile] if args.key?(:customer_profile) @detail_type = args[:detail_type] if args.key?(:detail_type) @technology_watchlist = args[:technology_watchlist] if args.key?(:technology_watchlist) end |