Class: Google::Apis::ThreatintelligenceV1beta::ConfigurationDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

Wrapper class that contains the union struct for all the various configuration detail specific classes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigurationDetail

Returns a new instance of ConfigurationDetail.



425
426
427
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customer_profileGoogle::Apis::ThreatintelligenceV1beta::CustomerProfileConfig

CustomerProfileConfig is the configuration for the customer profile. Corresponds to the JSON property customerProfile



417
418
419
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 417

def customer_profile
  @customer_profile
end

#detail_typeString

Output only. Name of the detail type. Will be set by the server during creation to the name of the field that is set in the detail union. Corresponds to the JSON property detailType

Returns:

  • (String)


423
424
425
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 423

def detail_type
  @detail_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



430
431
432
433
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 430

def update!(**args)
  @customer_profile = args[:customer_profile] if args.key?(:customer_profile)
  @detail_type = args[:detail_type] if args.key?(:detail_type)
end