Class: Google::Apis::ThreatintelligenceV1beta::ConfigurationRevision
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::ConfigurationRevision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
A ConfigurationRevision is a snapshot of a Configuration at a point in time. It is immutable.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#snapshot ⇒ Google::Apis::ThreatintelligenceV1beta::Configuration
A configuration represents a behavior an engine should follow when producing new findings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigurationRevision
constructor
A new instance of ConfigurationRevision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigurationRevision
Returns a new instance of ConfigurationRevision.
449 450 451 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 449 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the Revision was created
Corresponds to the JSON property createTime
435 436 437 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 435 def create_time @create_time end |
#name ⇒ String
Identifier. The name of the ConfigurationRevision Format: projects//
configurations//revisions/
Corresponds to the JSON property name
441 442 443 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 441 def name @name end |
#snapshot ⇒ Google::Apis::ThreatintelligenceV1beta::Configuration
A configuration represents a behavior an engine should follow when producing
new findings.
Corresponds to the JSON property snapshot
447 448 449 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 447 def snapshot @snapshot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
454 455 456 457 458 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 454 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @snapshot = args[:snapshot] if args.key?(:snapshot) end |