Class: Google::Apis::ThreatintelligenceV1beta::DataLeakFindingDetail
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::DataLeakFindingDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
A detail object for a Data Leak finding.
Instance Attribute Summary collapse
-
#document_id ⇒ String
Required.
-
#match_score ⇒ Float
Required.
-
#severity ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataLeakFindingDetail
constructor
A new instance of DataLeakFindingDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataLeakFindingDetail
Returns a new instance of DataLeakFindingDetail.
1092 1093 1094 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1092 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_id ⇒ String
Required. The unique identifier of the document that triggered the Data Leak
finding. This ID can be used to retrieve the content of the document for
further analysis.
Corresponds to the JSON property documentId
1076 1077 1078 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1076 def document_id @document_id end |
#match_score ⇒ Float
Required. Reference to the match score of the Data Leak finding. This is a
float value greater than 0 and less than or equal to 1 calculated by the
matching engine based on the similarity of the document and the user provided
configurations.
Corresponds to the JSON property matchScore
1084 1085 1086 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1084 def match_score @match_score end |
#severity ⇒ String
Required. The severity of the Data Leak finding. This indicates the potential
impact of the threat.
Corresponds to the JSON property severity
1090 1091 1092 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1090 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1097 1098 1099 1100 1101 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1097 def update!(**args) @document_id = args[:document_id] if args.key?(:document_id) @match_score = args[:match_score] if args.key?(:match_score) @severity = args[:severity] if args.key?(:severity) end |