Class: Google::Apis::ThreatintelligenceV1beta::DataLeakFindingDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

A detail object for a Data Leak finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataLeakFindingDetail

Returns a new instance of DataLeakFindingDetail.



1015
1016
1017
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_idString

Required. The unique identifier of the document that triggered the Data Leak finding. This ID can be used to retrieve the content of the document for further analysis. Corresponds to the JSON property documentId

Returns:

  • (String)


999
1000
1001
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 999

def document_id
  @document_id
end

#match_scoreFloat

Required. Reference to the match score of the Data Leak finding. This is a float value greater than 0 and less than or equal to 1 calculated by the matching engine based on the similarity of the document and the user provided configurations. Corresponds to the JSON property matchScore

Returns:

  • (Float)


1007
1008
1009
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1007

def match_score
  @match_score
end

#severityString

Required. The severity of the Data Leak finding. This indicates the potential impact of the threat. Corresponds to the JSON property severity

Returns:

  • (String)


1013
1014
1015
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1013

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1020
1021
1022
1023
1024
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1020

def update!(**args)
  @document_id = args[:document_id] if args.key?(:document_id)
  @match_score = args[:match_score] if args.key?(:match_score)
  @severity = args[:severity] if args.key?(:severity)
end