Class: Google::Apis::ThreatintelligenceV1beta::Evidence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

Details the evidence used to determine the relevance verdict.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Evidence

Returns a new instance of Evidence.



1053
1054
1055
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1053

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#common_themesArray<String>

A list of semantic themes or concepts found to be common, related, or aligned between the sources, supporting the verdict. Corresponds to the JSON property commonThemes

Returns:

  • (Array<String>)


1045
1046
1047
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1045

def common_themes
  @common_themes
end

#distinct_themesArray<String>

A list of semantic themes or descriptions unique to one source or semantically distant. Corresponds to the JSON property distinctThemes

Returns:

  • (Array<String>)


1051
1052
1053
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1051

def distinct_themes
  @distinct_themes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1058
1059
1060
1061
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1058

def update!(**args)
  @common_themes = args[:common_themes] if args.key?(:common_themes)
  @distinct_themes = args[:distinct_themes] if args.key?(:distinct_themes)
end