Class: Google::Apis::ThreatintelligenceV1beta::Finding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

A ‘stateless’ and a point in time event that a check produced a result of interest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Finding

Returns a new instance of Finding.



1261
1262
1263
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1261

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_summaryString

Optional. AI summary of the finding. Corresponds to the JSON property aiSummary

Returns:

  • (String)


1199
1200
1201
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1199

def ai_summary
  @ai_summary
end

#alertString

Optional. Name of the alert that this finding is bound to. Corresponds to the JSON property alert

Returns:

  • (String)


1204
1205
1206
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1204

def alert
  @alert
end

#auditGoogle::Apis::ThreatintelligenceV1beta::Audit

Tracks basic CRUD facts. Corresponds to the JSON property audit



1209
1210
1211
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1209

def audit
  @audit
end

#configurationsArray<String>

Optional. Configuration names that are bound to this finding. Corresponds to the JSON property configurations

Returns:

  • (Array<String>)


1214
1215
1216
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1214

def configurations
  @configurations
end

#detailGoogle::Apis::ThreatintelligenceV1beta::FindingDetail

Wrapper class that contains the union struct for all the various findings detail specific classes. Corresponds to the JSON property detail



1220
1221
1222
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1220

def detail
  @detail
end

#display_nameString

Required. A short descriptive title for the finding <= 250 chars. EX: "Actor ' baddy' offering $1000 for credentials of 'goodguy'". Corresponds to the JSON property displayName

Returns:

  • (String)


1226
1227
1228
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1226

def display_name
  @display_name
end

#nameString

Identifier. Server generated name for the finding (leave clear during creation) . Format: projects/project/findings/finding Corresponds to the JSON property name

Returns:

  • (String)


1232
1233
1234
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1232

def name
  @name
end

#providerString

Required. Logical source of this finding (name of the sub-engine). Corresponds to the JSON property provider

Returns:

  • (String)


1237
1238
1239
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1237

def provider
  @provider
end

#relevance_analysisGoogle::Apis::ThreatintelligenceV1beta::RelevanceAnalysis

Structured relevance analysis for a threat. Corresponds to the JSON property relevanceAnalysis



1242
1243
1244
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1242

def relevance_analysis
  @relevance_analysis
end

#reoccurrence_timesArray<String>

Output only. When identical finding (same labels and same details) has re- occurred. Corresponds to the JSON property reoccurrenceTimes

Returns:

  • (Array<String>)


1248
1249
1250
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1248

def reoccurrence_times
  @reoccurrence_times
end

#severityFloat

Optional. Deprecated: Use the severity_analysis field instead. Base severity score from the finding source. Corresponds to the JSON property severity

Returns:

  • (Float)


1254
1255
1256
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1254

def severity
  @severity
end

#severity_analysisGoogle::Apis::ThreatintelligenceV1beta::SeverityAnalysis

Structured severity analysis for a threat. Corresponds to the JSON property severityAnalysis



1259
1260
1261
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1259

def severity_analysis
  @severity_analysis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1266

def update!(**args)
  @ai_summary = args[:ai_summary] if args.key?(:ai_summary)
  @alert = args[:alert] if args.key?(:alert)
  @audit = args[:audit] if args.key?(:audit)
  @configurations = args[:configurations] if args.key?(:configurations)
  @detail = args[:detail] if args.key?(:detail)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @provider = args[:provider] if args.key?(:provider)
  @relevance_analysis = args[:relevance_analysis] if args.key?(:relevance_analysis)
  @reoccurrence_times = args[:reoccurrence_times] if args.key?(:reoccurrence_times)
  @severity = args[:severity] if args.key?(:severity)
  @severity_analysis = args[:severity_analysis] if args.key?(:severity_analysis)
end