Class: Google::Apis::ThreatintelligenceV1beta::Finding
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::Finding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
A ‘stateless’ and a point in time event that a check produced a result of interest.
Instance Attribute Summary collapse
-
#ai_summary ⇒ String
Optional.
-
#alert ⇒ String
Optional.
-
#audit ⇒ Google::Apis::ThreatintelligenceV1beta::Audit
Tracks basic CRUD facts.
-
#configurations ⇒ Array<String>
Optional.
-
#detail ⇒ Google::Apis::ThreatintelligenceV1beta::FindingDetail
Wrapper class that contains the union struct for all the various findings detail specific classes.
-
#display_name ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#provider ⇒ String
Required.
-
#relevance_analysis ⇒ Google::Apis::ThreatintelligenceV1beta::RelevanceAnalysis
Structured relevance analysis for a threat.
-
#reoccurrence_times ⇒ Array<String>
Output only.
-
#severity ⇒ Float
Optional.
-
#severity_analysis ⇒ Google::Apis::ThreatintelligenceV1beta::SeverityAnalysis
Structured severity analysis for a threat.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Finding
constructor
A new instance of Finding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Finding
Returns a new instance of Finding.
1215 1216 1217 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1215 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ai_summary ⇒ String
Optional. AI summary of the finding.
Corresponds to the JSON property aiSummary
1153 1154 1155 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1153 def ai_summary @ai_summary end |
#alert ⇒ String
Optional. Name of the alert that this finding is bound to.
Corresponds to the JSON property alert
1158 1159 1160 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1158 def alert @alert end |
#audit ⇒ Google::Apis::ThreatintelligenceV1beta::Audit
Tracks basic CRUD facts.
Corresponds to the JSON property audit
1163 1164 1165 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1163 def audit @audit end |
#configurations ⇒ Array<String>
Optional. Configuration names that are bound to this finding.
Corresponds to the JSON property configurations
1168 1169 1170 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1168 def configurations @configurations end |
#detail ⇒ Google::Apis::ThreatintelligenceV1beta::FindingDetail
Wrapper class that contains the union struct for all the various findings
detail specific classes.
Corresponds to the JSON property detail
1174 1175 1176 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1174 def detail @detail end |
#display_name ⇒ String
Required. A short descriptive title for the finding <= 250 chars. EX: "Actor '
baddy' offering $1000 for credentials of 'goodguy'".
Corresponds to the JSON property displayName
1180 1181 1182 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1180 def display_name @display_name end |
#name ⇒ String
Identifier. Server generated name for the finding (leave clear during creation)
. Format: projects/project/findings/finding
Corresponds to the JSON property name
1186 1187 1188 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1186 def name @name end |
#provider ⇒ String
Required. Logical source of this finding (name of the sub-engine).
Corresponds to the JSON property provider
1191 1192 1193 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1191 def provider @provider end |
#relevance_analysis ⇒ Google::Apis::ThreatintelligenceV1beta::RelevanceAnalysis
Structured relevance analysis for a threat.
Corresponds to the JSON property relevanceAnalysis
1196 1197 1198 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1196 def relevance_analysis @relevance_analysis end |
#reoccurrence_times ⇒ Array<String>
Output only. When identical finding (same labels and same details) has re-
occurred.
Corresponds to the JSON property reoccurrenceTimes
1202 1203 1204 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1202 def reoccurrence_times @reoccurrence_times end |
#severity ⇒ Float
Optional. Deprecated: Use the severity_analysis field instead. Base severity
score from the finding source.
Corresponds to the JSON property severity
1208 1209 1210 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1208 def severity @severity end |
#severity_analysis ⇒ Google::Apis::ThreatintelligenceV1beta::SeverityAnalysis
Structured severity analysis for a threat.
Corresponds to the JSON property severityAnalysis
1213 1214 1215 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1213 def severity_analysis @severity_analysis end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1220 def update!(**args) @ai_summary = args[:ai_summary] if args.key?(:ai_summary) @alert = args[:alert] if args.key?(:alert) @audit = args[:audit] if args.key?(:audit) @configurations = args[:configurations] if args.key?(:configurations) @detail = args[:detail] if args.key?(:detail) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @relevance_analysis = args[:relevance_analysis] if args.key?(:relevance_analysis) @reoccurrence_times = args[:reoccurrence_times] if args.key?(:reoccurrence_times) @severity = args[:severity] if args.key?(:severity) @severity_analysis = args[:severity_analysis] if args.key?(:severity_analysis) end |