Class: Google::Apis::ThreatintelligenceV1beta::FindingDetail
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::FindingDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
Wrapper class that contains the union struct for all the various findings detail specific classes.
Instance Attribute Summary collapse
-
#data_leak ⇒ Google::Apis::ThreatintelligenceV1beta::DataLeakFindingDetail
A detail object for a Data Leak finding.
-
#detail_type ⇒ String
Output only.
-
#initial_access_broker ⇒ Google::Apis::ThreatintelligenceV1beta::InitialAccessBrokerFindingDetail
A detail object for an Initial Access Broker (IAB) finding.
-
#insider_threat ⇒ Google::Apis::ThreatintelligenceV1beta::InsiderThreatFindingDetail
A detail object for a InsiderThreat finding.
-
#target_technology ⇒ Google::Apis::ThreatintelligenceV1beta::TargetTechnologyFindingDetail
Contains details for a technology watchlist finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FindingDetail
constructor
A new instance of FindingDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FindingDetail
Returns a new instance of FindingDetail.
1341 1342 1343 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_leak ⇒ Google::Apis::ThreatintelligenceV1beta::DataLeakFindingDetail
A detail object for a Data Leak finding.
Corresponds to the JSON property dataLeak
1318 1319 1320 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1318 def data_leak @data_leak end |
#detail_type ⇒ String
Output only. Name of the detail type. Will be set by the server during
creation to the name of the field that is set in the detail union.
Corresponds to the JSON property detailType
1324 1325 1326 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1324 def detail_type @detail_type end |
#initial_access_broker ⇒ Google::Apis::ThreatintelligenceV1beta::InitialAccessBrokerFindingDetail
A detail object for an Initial Access Broker (IAB) finding.
Corresponds to the JSON property initialAccessBroker
1329 1330 1331 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1329 def initial_access_broker @initial_access_broker end |
#insider_threat ⇒ Google::Apis::ThreatintelligenceV1beta::InsiderThreatFindingDetail
A detail object for a InsiderThreat finding.
Corresponds to the JSON property insiderThreat
1334 1335 1336 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1334 def insider_threat @insider_threat end |
#target_technology ⇒ Google::Apis::ThreatintelligenceV1beta::TargetTechnologyFindingDetail
Contains details for a technology watchlist finding.
Corresponds to the JSON property targetTechnology
1339 1340 1341 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1339 def target_technology @target_technology end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1346 1347 1348 1349 1350 1351 1352 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1346 def update!(**args) @data_leak = args[:data_leak] if args.key?(:data_leak) @detail_type = args[:detail_type] if args.key?(:detail_type) @initial_access_broker = args[:initial_access_broker] if args.key?(:initial_access_broker) @insider_threat = args[:insider_threat] if args.key?(:insider_threat) @target_technology = args[:target_technology] if args.key?(:target_technology) end |