Class: Google::Apis::ThreatintelligenceV1beta::FindingDetail
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::FindingDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
Wrapper class that contains the union struct for all the various findings detail specific classes.
Instance Attribute Summary collapse
-
#data_leak ⇒ Google::Apis::ThreatintelligenceV1beta::DataLeakFindingDetail
A detail object for a Data Leak finding.
-
#detail_type ⇒ String
Output only.
-
#initial_access_broker ⇒ Google::Apis::ThreatintelligenceV1beta::InitialAccessBrokerFindingDetail
A detail object for an Initial Access Broker (IAB) finding.
-
#insider_threat ⇒ Google::Apis::ThreatintelligenceV1beta::InsiderThreatFindingDetail
A detail object for a InsiderThreat finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FindingDetail
constructor
A new instance of FindingDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FindingDetail
Returns a new instance of FindingDetail.
1271 1272 1273 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_leak ⇒ Google::Apis::ThreatintelligenceV1beta::DataLeakFindingDetail
A detail object for a Data Leak finding.
Corresponds to the JSON property dataLeak
1253 1254 1255 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1253 def data_leak @data_leak end |
#detail_type ⇒ String
Output only. Name of the detail type. Will be set by the server during
creation to the name of the field that is set in the detail union.
Corresponds to the JSON property detailType
1259 1260 1261 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1259 def detail_type @detail_type end |
#initial_access_broker ⇒ Google::Apis::ThreatintelligenceV1beta::InitialAccessBrokerFindingDetail
A detail object for an Initial Access Broker (IAB) finding.
Corresponds to the JSON property initialAccessBroker
1264 1265 1266 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1264 def initial_access_broker @initial_access_broker end |
#insider_threat ⇒ Google::Apis::ThreatintelligenceV1beta::InsiderThreatFindingDetail
A detail object for a InsiderThreat finding.
Corresponds to the JSON property insiderThreat
1269 1270 1271 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1269 def insider_threat @insider_threat end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1276 1277 1278 1279 1280 1281 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1276 def update!(**args) @data_leak = args[:data_leak] if args.key?(:data_leak) @detail_type = args[:detail_type] if args.key?(:detail_type) @initial_access_broker = args[:initial_access_broker] if args.key?(:initial_access_broker) @insider_threat = args[:insider_threat] if args.key?(:insider_threat) end |