Class: Google::Apis::ThreatintelligenceV1beta::FindingDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

Wrapper class that contains the union struct for all the various findings detail specific classes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FindingDetail

Returns a new instance of FindingDetail.



1262
1263
1264
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1262

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_leakGoogle::Apis::ThreatintelligenceV1beta::DataLeakFindingDetail

A detail object for a Data Leak finding. Corresponds to the JSON property dataLeak



1244
1245
1246
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1244

def data_leak
  @data_leak
end

#detail_typeString

Output only. Name of the detail type. Will be set by the server during creation to the name of the field that is set in the detail union. Corresponds to the JSON property detailType

Returns:

  • (String)


1250
1251
1252
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1250

def detail_type
  @detail_type
end

#initial_access_brokerGoogle::Apis::ThreatintelligenceV1beta::InitialAccessBrokerFindingDetail

A detail object for an Initial Access Broker (IAB) finding. Corresponds to the JSON property initialAccessBroker



1255
1256
1257
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1255

def initial_access_broker
  @initial_access_broker
end

#insider_threatGoogle::Apis::ThreatintelligenceV1beta::InsiderThreatFindingDetail

A detail object for a InsiderThreat finding. Corresponds to the JSON property insiderThreat



1260
1261
1262
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1260

def insider_threat
  @insider_threat
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1267
1268
1269
1270
1271
1272
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1267

def update!(**args)
  @data_leak = args[:data_leak] if args.key?(:data_leak)
  @detail_type = args[:detail_type] if args.key?(:detail_type)
  @initial_access_broker = args[:initial_access_broker] if args.key?(:initial_access_broker)
  @insider_threat = args[:insider_threat] if args.key?(:insider_threat)
end