Class: Google::Apis::ThreatintelligenceV1beta::GenerateOrgProfileConfigurationRequest
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::GenerateOrgProfileConfigurationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
Request message for GenerateOrgProfileConfiguration.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#domain ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateOrgProfileConfigurationRequest
constructor
A new instance of GenerateOrgProfileConfigurationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateOrgProfileConfigurationRequest
Returns a new instance of GenerateOrgProfileConfigurationRequest.
1369 1370 1371 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. The display name of the organization to generate the profile for.
Corresponds to the JSON property displayName
1362 1363 1364 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1362 def display_name @display_name end |
#domain ⇒ String
Required. The domain of the organization to generate the profile for.
Corresponds to the JSON property domain
1367 1368 1369 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1367 def domain @domain end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1374 1375 1376 1377 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1374 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @domain = args[:domain] if args.key?(:domain) end |