Class: Google::Apis::ThreatintelligenceV1beta::GenerateOrgProfileConfigurationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

Request message for GenerateOrgProfileConfiguration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateOrgProfileConfigurationRequest

Returns a new instance of GenerateOrgProfileConfigurationRequest.



1341
1342
1343
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Required. The display name of the organization to generate the profile for. Corresponds to the JSON property displayName

Returns:

  • (String)


1334
1335
1336
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1334

def display_name
  @display_name
end

#domainString

Required. The domain of the organization to generate the profile for. Corresponds to the JSON property domain

Returns:

  • (String)


1339
1340
1341
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1339

def domain
  @domain
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1346
1347
1348
1349
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1346

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @domain = args[:domain] if args.key?(:domain)
end