Class: Google::Apis::ThreatintelligenceV1beta::GenerateOrgProfileConfigurationRequest
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::GenerateOrgProfileConfigurationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
Request message for GenerateOrgProfileConfiguration.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#domain ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateOrgProfileConfigurationRequest
constructor
A new instance of GenerateOrgProfileConfigurationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateOrgProfileConfigurationRequest
Returns a new instance of GenerateOrgProfileConfigurationRequest.
1290 1291 1292 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1290 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. The display name of the organization to generate the profile for.
Corresponds to the JSON property displayName
1283 1284 1285 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1283 def display_name @display_name end |
#domain ⇒ String
Required. The domain of the organization to generate the profile for.
Corresponds to the JSON property domain
1288 1289 1290 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1288 def domain @domain end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1295 1296 1297 1298 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1295 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @domain = args[:domain] if args.key?(:domain) end |