Class: Google::Apis::ThreatintelligenceV1beta::GenerateOrgProfileConfigurationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

Request message for GenerateOrgProfileConfiguration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateOrgProfileConfigurationRequest

Returns a new instance of GenerateOrgProfileConfigurationRequest.



1289
1290
1291
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Required. The display name of the organization to generate the profile for. Corresponds to the JSON property displayName

Returns:

  • (String)


1282
1283
1284
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1282

def display_name
  @display_name
end

#domainString

Required. The domain of the organization to generate the profile for. Corresponds to the JSON property domain

Returns:

  • (String)


1287
1288
1289
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1287

def domain
  @domain
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1294
1295
1296
1297
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1294

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @domain = args[:domain] if args.key?(:domain)
end