Class: Google::Apis::ThreatintelligenceV1beta::InitialAccessBrokerFindingDetail
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::InitialAccessBrokerFindingDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
A detail object for an Initial Access Broker (IAB) finding.
Instance Attribute Summary collapse
-
#document_id ⇒ String
Required.
-
#match_score ⇒ Float
Required.
-
#severity ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InitialAccessBrokerFindingDetail
constructor
A new instance of InitialAccessBrokerFindingDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InitialAccessBrokerFindingDetail
Returns a new instance of InitialAccessBrokerFindingDetail.
1350 1351 1352 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1350 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_id ⇒ String
Required. The unique identifier of the document that triggered the IAB finding.
This ID can be used to retrieve the content of the document for further
analysis.
Corresponds to the JSON property documentId
1335 1336 1337 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1335 def document_id @document_id end |
#match_score ⇒ Float
Required. Reference to the match score of the IAB finding. This is a float
value between 0 and 1 calculated by the matching engine based on the
similarity of the document and the user provided configurations.
Corresponds to the JSON property matchScore
1342 1343 1344 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1342 def match_score @match_score end |
#severity ⇒ String
Required. The severity of the IAB finding. This indicates the potential impact
of the threat.
Corresponds to the JSON property severity
1348 1349 1350 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1348 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1355 1356 1357 1358 1359 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1355 def update!(**args) @document_id = args[:document_id] if args.key?(:document_id) @match_score = args[:match_score] if args.key?(:match_score) @severity = args[:severity] if args.key?(:severity) end |