Class: Google::Apis::ThreatintelligenceV1beta::InsiderThreatFindingDetail
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::InsiderThreatFindingDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
A detail object for a InsiderThreat finding.
Instance Attribute Summary collapse
-
#document_id ⇒ String
Required.
-
#match_score ⇒ Float
Required.
-
#severity ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InsiderThreatFindingDetail
constructor
A new instance of InsiderThreatFindingDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InsiderThreatFindingDetail
Returns a new instance of InsiderThreatFindingDetail.
1493 1494 1495 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_id ⇒ String
Required. The unique identifier of the document that triggered the
InsiderThreat finding. This ID can be used to retrieve the content of the
document for further analysis.
Corresponds to the JSON property documentId
1477 1478 1479 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1477 def document_id @document_id end |
#match_score ⇒ Float
Required. Reference to the match score of the InsiderThreat finding. This is a
float value greater than 0 and less than or equal to 1 calculated by the
matching engine based on the similarity of the document and the user provided
configurations.
Corresponds to the JSON property matchScore
1485 1486 1487 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1485 def match_score @match_score end |
#severity ⇒ String
Required. The severity of the InsiderThreat finding. This indicates the
potential impact of the threat.
Corresponds to the JSON property severity
1491 1492 1493 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1491 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1498 1499 1500 1501 1502 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1498 def update!(**args) @document_id = args[:document_id] if args.key?(:document_id) @match_score = args[:match_score] if args.key?(:match_score) @severity = args[:severity] if args.key?(:severity) end |