Class: Google::Apis::ThreatintelligenceV1beta::InsiderThreatFindingDetail
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::InsiderThreatFindingDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
A detail object for a InsiderThreat finding.
Instance Attribute Summary collapse
-
#document_id ⇒ String
Required.
-
#match_score ⇒ Float
Required.
-
#severity ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InsiderThreatFindingDetail
constructor
A new instance of InsiderThreatFindingDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InsiderThreatFindingDetail
Returns a new instance of InsiderThreatFindingDetail.
1414 1415 1416 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1414 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_id ⇒ String
Required. The unique identifier of the document that triggered the
InsiderThreat finding. This ID can be used to retrieve the content of the
document for further analysis.
Corresponds to the JSON property documentId
1398 1399 1400 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1398 def document_id @document_id end |
#match_score ⇒ Float
Required. Reference to the match score of the InsiderThreat finding. This is a
float value greater than 0 and less than or equal to 1 calculated by the
matching engine based on the similarity of the document and the user provided
configurations.
Corresponds to the JSON property matchScore
1406 1407 1408 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1406 def match_score @match_score end |
#severity ⇒ String
Required. The severity of the InsiderThreat finding. This indicates the
potential impact of the threat.
Corresponds to the JSON property severity
1412 1413 1414 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1412 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1419 1420 1421 1422 1423 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1419 def update!(**args) @document_id = args[:document_id] if args.key?(:document_id) @match_score = args[:match_score] if args.key?(:match_score) @severity = args[:severity] if args.key?(:severity) end |