Class: Google::Apis::ThreatintelligenceV1beta::InsiderThreatFindingDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

A detail object for a InsiderThreat finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsiderThreatFindingDetail

Returns a new instance of InsiderThreatFindingDetail.



1413
1414
1415
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_idString

Required. The unique identifier of the document that triggered the InsiderThreat finding. This ID can be used to retrieve the content of the document for further analysis. Corresponds to the JSON property documentId

Returns:

  • (String)


1397
1398
1399
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1397

def document_id
  @document_id
end

#match_scoreFloat

Required. Reference to the match score of the InsiderThreat finding. This is a float value greater than 0 and less than or equal to 1 calculated by the matching engine based on the similarity of the document and the user provided configurations. Corresponds to the JSON property matchScore

Returns:

  • (Float)


1405
1406
1407
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1405

def match_score
  @match_score
end

#severityString

Required. The severity of the InsiderThreat finding. This indicates the potential impact of the threat. Corresponds to the JSON property severity

Returns:

  • (String)


1411
1412
1413
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1411

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1418
1419
1420
1421
1422
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1418

def update!(**args)
  @document_id = args[:document_id] if args.key?(:document_id)
  @match_score = args[:match_score] if args.key?(:match_score)
  @severity = args[:severity] if args.key?(:severity)
end