Class: Google::Apis::ThreatintelligenceV1beta::LegacyMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::LegacyMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
Legacy metadata associated with this scenario/monitor.
Instance Attribute Summary collapse
-
#aggregation_enabled ⇒ Boolean
(also: #aggregation_enabled?)
Optional.
-
#aggregation_similarity ⇒ Float
Optional.
-
#condition_version ⇒ Fixnum
Optional.
-
#creator_user_id ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#disabled_code ⇒ String
Optional.
-
#disabled_reason ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#email_notification_enabled ⇒ Boolean
(also: #email_notification_enabled?)
Optional.
-
#email_notification_immediate ⇒ Boolean
(also: #email_notification_immediate?)
Optional.
-
#legacy_monitor_id ⇒ String
Optional.
-
#stale_time ⇒ String
Optional.
-
#template_id ⇒ String
Optional.
-
#tenant_id ⇒ String
Optional.
-
#updater_user_id ⇒ String
Optional.
-
#version ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LegacyMetadata
constructor
A new instance of LegacyMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LegacyMetadata
Returns a new instance of LegacyMetadata.
1623 1624 1625 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1623 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregation_enabled ⇒ Boolean Also known as: aggregation_enabled?
Optional. Whether aggregation is enabled for alerts from this monitor.
Corresponds to the JSON property aggregationEnabled
1543 1544 1545 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1543 def aggregation_enabled @aggregation_enabled end |
#aggregation_similarity ⇒ Float
Optional. Similarity threshold for aggregation.
Corresponds to the JSON property aggregationSimilarity
1549 1550 1551 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1549 def aggregation_similarity @aggregation_similarity end |
#condition_version ⇒ Fixnum
Optional. Version of the condition schema.
Corresponds to the JSON property conditionVersion
1554 1555 1556 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1554 def condition_version @condition_version end |
#creator_user_id ⇒ String
Optional. User ID who created the monitor.
Corresponds to the JSON property creatorUserId
1559 1560 1561 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1559 def creator_user_id @creator_user_id end |
#description ⇒ String
Optional. Description of the legacy monitor.
Corresponds to the JSON property description
1564 1565 1566 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1564 def description @description end |
#disabled_code ⇒ String
Optional. Code indicating why the monitor is disabled (if applicable).
Corresponds to the JSON property disabledCode
1569 1570 1571 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1569 def disabled_code @disabled_code end |
#disabled_reason ⇒ String
Optional. Reason why the monitor is disabled (if applicable).
Corresponds to the JSON property disabledReason
1574 1575 1576 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1574 def disabled_reason @disabled_reason end |
#display_name ⇒ String
Optional. Name of the legacy monitor.
Corresponds to the JSON property displayName
1579 1580 1581 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1579 def display_name @display_name end |
#email_notification_enabled ⇒ Boolean Also known as: email_notification_enabled?
Optional. Whether email notifications are enabled.
Corresponds to the JSON property emailNotificationEnabled
1584 1585 1586 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1584 def email_notification_enabled @email_notification_enabled end |
#email_notification_immediate ⇒ Boolean Also known as: email_notification_immediate?
Optional. Whether email notifications are intermediate/immediate.
Corresponds to the JSON property emailNotificationImmediate
1590 1591 1592 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1590 def email_notification_immediate @email_notification_immediate end |
#legacy_monitor_id ⇒ String
Optional. Unique identifier of the legacy monitor.
Corresponds to the JSON property legacyMonitorId
1596 1597 1598 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1596 def legacy_monitor_id @legacy_monitor_id end |
#stale_time ⇒ String
Optional. Time the legacy monitor was considered stale.
Corresponds to the JSON property staleTime
1601 1602 1603 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1601 def stale_time @stale_time end |
#template_id ⇒ String
Optional. ID of the template this monitor was created from.
Corresponds to the JSON property templateId
1606 1607 1608 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1606 def template_id @template_id end |
#tenant_id ⇒ String
Optional. ID of the tenant owning the monitor.
Corresponds to the JSON property tenantId
1611 1612 1613 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1611 def tenant_id @tenant_id end |
#updater_user_id ⇒ String
Optional. User ID who last updated the monitor.
Corresponds to the JSON property updaterUserId
1616 1617 1618 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1616 def updater_user_id @updater_user_id end |
#version ⇒ Fixnum
Optional. Version of the monitor configuration.
Corresponds to the JSON property version
1621 1622 1623 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1621 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1628 def update!(**args) @aggregation_enabled = args[:aggregation_enabled] if args.key?(:aggregation_enabled) @aggregation_similarity = args[:aggregation_similarity] if args.key?(:aggregation_similarity) @condition_version = args[:condition_version] if args.key?(:condition_version) @creator_user_id = args[:creator_user_id] if args.key?(:creator_user_id) @description = args[:description] if args.key?(:description) @disabled_code = args[:disabled_code] if args.key?(:disabled_code) @disabled_reason = args[:disabled_reason] if args.key?(:disabled_reason) @display_name = args[:display_name] if args.key?(:display_name) @email_notification_enabled = args[:email_notification_enabled] if args.key?(:email_notification_enabled) @email_notification_immediate = args[:email_notification_immediate] if args.key?(:email_notification_immediate) @legacy_monitor_id = args[:legacy_monitor_id] if args.key?(:legacy_monitor_id) @stale_time = args[:stale_time] if args.key?(:stale_time) @template_id = args[:template_id] if args.key?(:template_id) @tenant_id = args[:tenant_id] if args.key?(:tenant_id) @updater_user_id = args[:updater_user_id] if args.key?(:updater_user_id) @version = args[:version] if args.key?(:version) end |