Class: Google::Apis::ThreatintelligenceV1beta::ListConfigurationRevisionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

Response message for ListConfigurationRevisions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListConfigurationRevisionsResponse

Returns a new instance of ListConfigurationRevisionsResponse.



1466
1467
1468
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1459
1460
1461
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1459

def next_page_token
  @next_page_token
end

#revisionsArray<Google::Apis::ThreatintelligenceV1beta::ConfigurationRevision>

The Configuration Revisions associated with the specified Configuration Corresponds to the JSON property revisions



1464
1465
1466
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1464

def revisions
  @revisions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1471
1472
1473
1474
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1471

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @revisions = args[:revisions] if args.key?(:revisions)
end