Class: Google::Apis::ThreatintelligenceV1beta::ListConfigurationRevisionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb

Overview

Response message for ListConfigurationRevisions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListConfigurationRevisionsResponse

Returns a new instance of ListConfigurationRevisionsResponse.



1465
1466
1467
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1465

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1458
1459
1460
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1458

def next_page_token
  @next_page_token
end

#revisionsArray<Google::Apis::ThreatintelligenceV1beta::ConfigurationRevision>

The Configuration Revisions associated with the specified Configuration Corresponds to the JSON property revisions



1463
1464
1465
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1463

def revisions
  @revisions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1470
1471
1472
1473
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1470

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @revisions = args[:revisions] if args.key?(:revisions)
end