Class: Google::Apis::ThreatintelligenceV1beta::RelevanceAnalysis
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::RelevanceAnalysis
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
Structured relevance analysis for a threat.
Instance Attribute Summary collapse
-
#confidence ⇒ String
The level of confidence in the given verdict.
-
#evidence ⇒ Google::Apis::ThreatintelligenceV1beta::Evidence
Details the evidence used to determine the relevance verdict.
-
#reasoning ⇒ String
Human-readable explanation from the matcher, detailing why a particular result is considered relevant or not relevant.
-
#relevance_level ⇒ String
The level of relevance.
-
#relevant ⇒ Boolean
(also: #relevant?)
Indicates whether the threat is considered relevant.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RelevanceAnalysis
constructor
A new instance of RelevanceAnalysis.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RelevanceAnalysis
Returns a new instance of RelevanceAnalysis.
1775 1776 1777 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1775 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ String
The level of confidence in the given verdict.
Corresponds to the JSON property confidence
1751 1752 1753 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1751 def confidence @confidence end |
#evidence ⇒ Google::Apis::ThreatintelligenceV1beta::Evidence
Details the evidence used to determine the relevance verdict.
Corresponds to the JSON property evidence
1756 1757 1758 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1756 def evidence @evidence end |
#reasoning ⇒ String
Human-readable explanation from the matcher, detailing why a particular result
is considered relevant or not relevant.
Corresponds to the JSON property reasoning
1762 1763 1764 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1762 def reasoning @reasoning end |
#relevance_level ⇒ String
The level of relevance.
Corresponds to the JSON property relevanceLevel
1767 1768 1769 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1767 def relevance_level @relevance_level end |
#relevant ⇒ Boolean Also known as: relevant?
Indicates whether the threat is considered relevant.
Corresponds to the JSON property relevant
1772 1773 1774 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1772 def relevant @relevant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1780 1781 1782 1783 1784 1785 1786 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1780 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @evidence = args[:evidence] if args.key?(:evidence) @reasoning = args[:reasoning] if args.key?(:reasoning) @relevance_level = args[:relevance_level] if args.key?(:relevance_level) @relevant = args[:relevant] if args.key?(:relevant) end |