Class: Google::Apis::ThreatintelligenceV1beta::SeverityAnalysis
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::SeverityAnalysis
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
Structured severity analysis for a threat.
Instance Attribute Summary collapse
-
#confidence ⇒ String
The level of confidence in the given verdict.
-
#reasoning ⇒ String
Human-readable explanation from the model, detailing why a particular result is considered to have a certain severity.
-
#severity_level ⇒ String
The level of severity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SeverityAnalysis
constructor
A new instance of SeverityAnalysis.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SeverityAnalysis
Returns a new instance of SeverityAnalysis.
1972 1973 1974 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1972 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ String
The level of confidence in the given verdict.
Corresponds to the JSON property confidence
1959 1960 1961 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1959 def confidence @confidence end |
#reasoning ⇒ String
Human-readable explanation from the model, detailing why a particular result
is considered to have a certain severity.
Corresponds to the JSON property reasoning
1965 1966 1967 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1965 def reasoning @reasoning end |
#severity_level ⇒ String
The level of severity.
Corresponds to the JSON property severityLevel
1970 1971 1972 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1970 def severity_level @severity_level end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1977 1978 1979 1980 1981 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1977 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @reasoning = args[:reasoning] if args.key?(:reasoning) @severity_level = args[:severity_level] if args.key?(:severity_level) end |