Class: Google::Apis::ThreatintelligenceV1beta::SeverityAnalysis
- Inherits:
-
Object
- Object
- Google::Apis::ThreatintelligenceV1beta::SeverityAnalysis
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/threatintelligence_v1beta/classes.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb,
lib/google/apis/threatintelligence_v1beta/representations.rb
Overview
Structured severity analysis for a threat.
Instance Attribute Summary collapse
-
#confidence ⇒ String
The level of confidence in the given verdict.
-
#reasoning ⇒ String
Human-readable explanation from the model, detailing why a particular result is considered to have a certain severity.
-
#severity_level ⇒ String
The level of severity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SeverityAnalysis
constructor
A new instance of SeverityAnalysis.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SeverityAnalysis
Returns a new instance of SeverityAnalysis.
1834 1835 1836 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1834 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ String
The level of confidence in the given verdict.
Corresponds to the JSON property confidence
1821 1822 1823 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1821 def confidence @confidence end |
#reasoning ⇒ String
Human-readable explanation from the model, detailing why a particular result
is considered to have a certain severity.
Corresponds to the JSON property reasoning
1827 1828 1829 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1827 def reasoning @reasoning end |
#severity_level ⇒ String
The level of severity.
Corresponds to the JSON property severityLevel
1832 1833 1834 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1832 def severity_level @severity_level end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1839 1840 1841 1842 1843 |
# File 'lib/google/apis/threatintelligence_v1beta/classes.rb', line 1839 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @reasoning = args[:reasoning] if args.key?(:reasoning) @severity_level = args[:severity_level] if args.key?(:severity_level) end |