Class: Google::Apis::ThreatintelligenceV1beta::ThreatIntelligenceServiceService

Inherits:
Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/threatintelligence_v1beta/service.rb

Overview

Threat Intelligence API

threatintelligence.googleapis.com API.

Examples:

require 'google/apis/threatintelligence_v1beta'

Threatintelligence = Google::Apis::ThreatintelligenceV1beta # Alias the module
service = Threatintelligence::ThreatIntelligenceServiceService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://threatintelligence.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeThreatIntelligenceServiceService

Returns a new instance of ThreatIntelligenceServiceService.



47
48
49
50
51
52
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 47

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-threatintelligence_v1beta',
        client_version: Google::Apis::ThreatintelligenceV1beta::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



40
41
42
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 40

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



45
46
47
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 45

def quota_user
  @quota_user
end

Instance Method Details

#benign_project_alert(name, mark_alert_as_benign_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert

Marks an alert as benign - BENIGN.

Parameters:

  • name (String)

    Required. Name of the alert to mark as a benign. Format: projects/project/ alerts/alert

  • mark_alert_as_benign_request_object (Google::Apis::ThreatintelligenceV1beta::MarkAlertAsBenignRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



110
111
112
113
114
115
116
117
118
119
120
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 110

def benign_project_alert(name, mark_alert_as_benign_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta/{+name}:benign', options)
  command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsBenignRequest::Representation
  command.request_object = mark_alert_as_benign_request_object
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#duplicate_project_alert(name, mark_alert_as_duplicate_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert

Marks an alert as a duplicate of another alert. - DUPLICATE.

Parameters:

  • name (String)

    Required. Name of the alert to mark as a duplicate. Format: projects/project/ alerts/alert

  • mark_alert_as_duplicate_request_object (Google::Apis::ThreatintelligenceV1beta::MarkAlertAsDuplicateRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



144
145
146
147
148
149
150
151
152
153
154
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 144

def duplicate_project_alert(name, mark_alert_as_duplicate_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta/{+name}:duplicate', options)
  command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsDuplicateRequest::Representation
  command.request_object = mark_alert_as_duplicate_request_object
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#enumerate_project_alert_facets(parent, filter: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::EnumerateAlertFacetsResponse

EnumerateAlertFacets returns the facets and the number of alerts that meet the filter criteria and have that value for each facet.

Parameters:

  • parent (String)

    Required. Parent of the alerts.

  • filter (String) (defaults to: nil)

    Optional. Filter on what alerts will be enumerated.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



179
180
181
182
183
184
185
186
187
188
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 179

def enumerate_project_alert_facets(parent, filter: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta/{+parent}/alerts:enumerateFacets', options)
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::EnumerateAlertFacetsResponse::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::EnumerateAlertFacetsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#escalate_project_alert(name, mark_alert_as_escalated_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert

Marks an alert as escalated - ESCALATED.

Parameters:

  • name (String)

    Required. Name of the alert to mark as escalated. Format: projects/project/ alerts/alert

  • mark_alert_as_escalated_request_object (Google::Apis::ThreatintelligenceV1beta::MarkAlertAsEscalatedRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



212
213
214
215
216
217
218
219
220
221
222
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 212

def escalate_project_alert(name, mark_alert_as_escalated_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta/{+name}:escalate', options)
  command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsEscalatedRequest::Representation
  command.request_object = mark_alert_as_escalated_request_object
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#false_project_alert_positive(name, mark_alert_as_false_positive_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert

Marks an alert as a false positive - FALSE_POSITIVE.

Parameters:

  • name (String)

    Required. Name of the alert to mark as a false positive. Format: projects/ project/alerts/alert

  • mark_alert_as_false_positive_request_object (Google::Apis::ThreatintelligenceV1beta::MarkAlertAsFalsePositiveRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



246
247
248
249
250
251
252
253
254
255
256
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 246

def false_project_alert_positive(name, mark_alert_as_false_positive_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta/{+name}:falsePositive', options)
  command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsFalsePositiveRequest::Representation
  command.request_object = mark_alert_as_false_positive_request_object
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#generate_project_org_profile_configuration(name, generate_org_profile_configuration_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Operation

Triggers the generation of a Customer Profile for a project.

Parameters:

  • name (String)

    Required. The name of the project to generate the profile for. Format: projects/project

  • generate_org_profile_configuration_request_object (Google::Apis::ThreatintelligenceV1beta::GenerateOrgProfileConfigurationRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



76
77
78
79
80
81
82
83
84
85
86
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 76

def generate_project_org_profile_configuration(name, generate_org_profile_configuration_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta/{+name}:generateOrgProfile', options)
  command.request_representation = Google::Apis::ThreatintelligenceV1beta::GenerateOrgProfileConfigurationRequest::Representation
  command.request_object = generate_org_profile_configuration_request_object
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::Operation::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_alert(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert

Get an alert by name.

Parameters:

  • name (String)

    Required. Name of the alert to get. Format: projects/project/alerts/alert

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



278
279
280
281
282
283
284
285
286
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 278

def get_project_alert(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta/{+name}', options)
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_alert_document(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::AlertDocument

Gets a specific document associated with an alert.

Parameters:

  • name (String)

    Required. Name of the alert document to get. Format: projects/project/alerts/ alert/documents/document

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



539
540
541
542
543
544
545
546
547
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 539

def get_project_alert_document(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta/{+name}', options)
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::AlertDocument::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::AlertDocument
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_configuration(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Configuration

Get a configuration by name.

Parameters:

  • name (String)

    Required. Name of the configuration to get. Format: vaults/vault/ configurations/configuration

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



570
571
572
573
574
575
576
577
578
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 570

def get_project_configuration(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta/{+name}', options)
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::Configuration::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::Configuration
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_finding(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Finding

Get a finding by name. The name field should have the format: projects/ project/findings/finding``

Parameters:

  • name (String)

    Required. Name of the finding to get.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



725
726
727
728
729
730
731
732
733
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 725

def get_project_finding(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta/{+name}', options)
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::Finding::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::Finding
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_alerts(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::ListAlertsResponse

Get a list of alerts that meet the filter criteria.

Parameters:

  • parent (String)

    Required. Parent of the alerts. Format: projects/project

  • filter (String) (defaults to: nil)

    Optional. Filter criteria. Supported fields for filtering include: * audit. create_time * audit.creator * audit.update_time * audit.updater * detail.data_leak.discovery_document_ids * detail.data_leak.severity * detail.detail_type * detail.initial_access_broker.discovery_document_ids * detail.initial_access_broker.severity * detail.insider_threat. discovery_document_ids * detail.insider_threat.severity * finding_count * priority_analysis.priority_level * relevance_analysis.confidence * relevance_analysis.relevance_level * relevance_analysis.relevant * severity_analysis.severity_level * state Examples: * detail.detail_type = " initial_access_broker" * detail.detail_type != "data_leak" * detail. insider_threat.severity = "HIGH" * audit.create_time >= "2026-04-03T00:00: 00Z" AND audit.create_time < "2026-04-06T00:00:00Z" * state = "NEW" OR state = "TRIAGED" * severity_analysis.severity_level = "SEVERITY_LEVEL_CRITICAL"

  • order_by (String) (defaults to: nil)

    Optional. Order by criteria in the csv format: "field1, field2 desc" or " field1, field2" or "field1 asc, field2". If a field is specified without asc or desc, ascending order is used by default. Supported fields for ordering are identical to those supported for filtering. Examples: * audit.create_time desc * audit.update_time asc * audit.create_time desc, severity_analysis. severity_level desc

  • page_size (Fixnum) (defaults to: nil)

    Optional. Page size. Default to 100 alerts per page. Maximum is 1000 alerts per page.

  • page_token (String) (defaults to: nil)

    Optional. Page token to retrieve the next page of results.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 334

def list_project_alerts(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta/{+parent}/alerts', options)
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::ListAlertsResponse::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::ListAlertsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['orderBy'] = order_by unless order_by.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_configuration_revisions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::ListConfigurationRevisionsResponse

List configuration revisions that meet the filter criteria.

Parameters:

  • parent (String)

    Required. The name of the Configuration to retrieve Revisions for

  • filter (String) (defaults to: nil)

    Optional. An AIP-160 filter string

  • order_by (String) (defaults to: nil)

    Optional. Specify ordering of response

  • page_size (Fixnum) (defaults to: nil)

    Optional. Page Size

  • page_token (String) (defaults to: nil)

    Optional. A page token provided by the API

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



690
691
692
693
694
695
696
697
698
699
700
701
702
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 690

def list_project_configuration_revisions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta/{+parent}/revisions', options)
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::ListConfigurationRevisionsResponse::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::ListConfigurationRevisionsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['orderBy'] = order_by unless order_by.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_configurations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::ListConfigurationsResponse

Get a list of configurations that meet the filter criteria.

Parameters:

  • parent (String)

    Required. Parent of the configuration. Format: vaults/vault

  • filter (String) (defaults to: nil)

    Optional. Filter criteria.

  • order_by (String) (defaults to: nil)

    Optional. Order by criteria in the csv format: "field1,field2 desc" or "field1, field2" or "field1 asc, field2".

  • page_size (Fixnum) (defaults to: nil)

    Optional. Page size.

  • page_token (String) (defaults to: nil)

    Optional. Page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



609
610
611
612
613
614
615
616
617
618
619
620
621
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 609

def list_project_configurations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta/{+parent}/configurations', options)
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::ListConfigurationsResponse::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::ListConfigurationsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['orderBy'] = order_by unless order_by.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_findings(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::ListFindingsResponse

Get a list of findings that meet the filter criteria. The parent field in ListFindingsRequest should have the format: projects/project

Parameters:

  • parent (String)

    Required. Parent of the findings.

  • filter (String) (defaults to: nil)

    Optional. Filter criteria.

  • order_by (String) (defaults to: nil)

    Optional. Order by criteria in the csv format: "field1,field2 desc" or "field1, field2" or "field1 asc, field2".

  • page_size (Fixnum) (defaults to: nil)

    Optional. Page size.

  • page_token (String) (defaults to: nil)

    Optional. Page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



765
766
767
768
769
770
771
772
773
774
775
776
777
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 765

def list_project_findings(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta/{+parent}/findings', options)
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::ListFindingsResponse::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::ListFindingsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['orderBy'] = order_by unless order_by.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#not_project_alert_actionable(name, mark_alert_as_not_actionable_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert

Marks an alert as not actionable - NOT_ACTIONABLE.

Parameters:

  • name (String)

    Required. Name of the alert to mark as a not actionable. Format: projects/ project/alerts/alert

  • mark_alert_as_not_actionable_request_object (Google::Apis::ThreatintelligenceV1beta::MarkAlertAsNotActionableRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



370
371
372
373
374
375
376
377
378
379
380
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 370

def not_project_alert_actionable(name, mark_alert_as_not_actionable_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta/{+name}:notActionable', options)
  command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsNotActionableRequest::Representation
  command.request_object = mark_alert_as_not_actionable_request_object
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#read_project_alert(name, mark_alert_as_read_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert

Marks an alert as read - READ.

Parameters:

  • name (String)

    Required. Name of the alert to mark as read. Format: projects/project/alerts/ alert

  • mark_alert_as_read_request_object (Google::Apis::ThreatintelligenceV1beta::MarkAlertAsReadRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



404
405
406
407
408
409
410
411
412
413
414
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 404

def read_project_alert(name, mark_alert_as_read_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta/{+name}:read', options)
  command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsReadRequest::Representation
  command.request_object = mark_alert_as_read_request_object
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#resolve_project_alert(name, mark_alert_as_resolved_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert

Marks an alert to closed state - RESOLVED.

Parameters:

  • name (String)

    Required. Name of the alert to mark as resolved. Format: projects/project/ alerts/alert

  • mark_alert_as_resolved_request_object (Google::Apis::ThreatintelligenceV1beta::MarkAlertAsResolvedRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



438
439
440
441
442
443
444
445
446
447
448
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 438

def resolve_project_alert(name, mark_alert_as_resolved_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta/{+name}:resolve', options)
  command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsResolvedRequest::Representation
  command.request_object = mark_alert_as_resolved_request_object
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#search_project_findings(parent, order_by: nil, page_size: nil, page_token: nil, query: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::SearchFindingsResponse

SearchFindings is a more powerful version of ListFindings that supports complex queries like "findings for alerts" using functions such as has_alert in the query string. The parent field in SearchFindingsRequest should have the format: projects/project Example to search for findings for a specific issue: has_alert("name=\"projects/gti-12345/alerts/alert-12345\"")

Parameters:

  • parent (String)

    Required. Parent of the findings. Format: vaults/vault

  • order_by (String) (defaults to: nil)

    Optional. Order by criteria in the csv format: "field1,field2 desc" or "field1, field2" or "field1 asc, field2".

  • page_size (Fixnum) (defaults to: nil)

    Optional. Page size.

  • page_token (String) (defaults to: nil)

    Optional. Page token.

  • query (String) (defaults to: nil)

    Optional. Query on what findings will be returned. This supports the same filter criteria as FindingService.ListFindings as well as the following relationship query has_alert. Example: - has_alert("name=\"projects/gti- 12345/alerts/alert-12345\"")

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



815
816
817
818
819
820
821
822
823
824
825
826
827
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 815

def search_project_findings(parent, order_by: nil, page_size: nil, page_token: nil, query: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta/{+parent}/findings:search', options)
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::SearchFindingsResponse::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::SearchFindingsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['orderBy'] = order_by unless order_by.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['query'] = query unless query.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#track_project_alert_externally(name, mark_alert_as_tracked_externally_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert

Marks an alert as tracked externally - TRACKED_EXTERNALLY.

Parameters:

  • name (String)

    Required. Name of the alert to mark as tracked externally. Format: projects/ project/alerts/alert

  • mark_alert_as_tracked_externally_request_object (Google::Apis::ThreatintelligenceV1beta::MarkAlertAsTrackedExternallyRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



472
473
474
475
476
477
478
479
480
481
482
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 472

def track_project_alert_externally(name, mark_alert_as_tracked_externally_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta/{+name}:trackExternally', options)
  command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsTrackedExternallyRequest::Representation
  command.request_object = mark_alert_as_tracked_externally_request_object
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#triage_project_alert(name, mark_alert_as_triaged_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert

Marks an alert as triaged - TRIAGED.

Parameters:

  • name (String)

    Required. Name of the alert to mark as a triaged. Format: projects/project/ alerts/alert

  • mark_alert_as_triaged_request_object (Google::Apis::ThreatintelligenceV1beta::MarkAlertAsTriagedRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



506
507
508
509
510
511
512
513
514
515
516
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 506

def triage_project_alert(name, mark_alert_as_triaged_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta/{+name}:triage', options)
  command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsTriagedRequest::Representation
  command.request_object = mark_alert_as_triaged_request_object
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#upsert_project_configuration(parent, configuration_object = nil, publish_time: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::UpsertConfigurationResponse

Creates or updates a configuration.

Parameters:

  • parent (String)

    Required. Parent of the configuration.

  • configuration_object (Google::Apis::ThreatintelligenceV1beta::Configuration) (defaults to: nil)
  • publish_time (String) (defaults to: nil)

    Optional. Time that the configuration should be considered to have been published. This is an advanced feature used when onboarding and bulk loading data from other systems. Do not set this field without consulting with the API team.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 649

def upsert_project_configuration(parent, configuration_object = nil, publish_time: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta/{+parent}/configurations:upsert', options)
  command.request_representation = Google::Apis::ThreatintelligenceV1beta::Configuration::Representation
  command.request_object = configuration_object
  command.response_representation = Google::Apis::ThreatintelligenceV1beta::UpsertConfigurationResponse::Representation
  command.response_class = Google::Apis::ThreatintelligenceV1beta::UpsertConfigurationResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['publishTime'] = publish_time unless publish_time.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end