Class: Google::Apis::ThreatintelligenceV1beta::ThreatIntelligenceServiceService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ThreatintelligenceV1beta::ThreatIntelligenceServiceService
- Defined in:
- lib/google/apis/threatintelligence_v1beta/service.rb
Overview
Threat Intelligence API
threatintelligence.googleapis.com API.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://threatintelligence.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#benign_project_alert(name, mark_alert_as_benign_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as benign - BENIGN.
-
#duplicate_project_alert(name, mark_alert_as_duplicate_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as a duplicate of another alert.
-
#enumerate_project_alert_facets(parent, filter: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::EnumerateAlertFacetsResponse
EnumerateAlertFacets returns the facets and the number of alerts that meet the filter criteria and have that value for each facet.
-
#escalate_project_alert(name, mark_alert_as_escalated_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as escalated - ESCALATED.
-
#false_project_alert_positive(name, mark_alert_as_false_positive_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as a false positive - FALSE_POSITIVE.
-
#generate_project_org_profile_configuration(name, generate_org_profile_configuration_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Operation
Triggers the generation of a Customer Profile for a project.
-
#get_project_alert(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Get an alert by name.
-
#get_project_alert_document(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::AlertDocument
Gets a specific document associated with an alert.
-
#get_project_configuration(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Configuration
Get a configuration by name.
-
#get_project_finding(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Finding
Get a finding by name.
-
#initialize ⇒ ThreatIntelligenceServiceService
constructor
A new instance of ThreatIntelligenceServiceService.
-
#list_project_alerts(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::ListAlertsResponse
Get a list of alerts that meet the filter criteria.
-
#list_project_configuration_revisions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::ListConfigurationRevisionsResponse
List configuration revisions that meet the filter criteria.
-
#list_project_configurations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::ListConfigurationsResponse
Get a list of configurations that meet the filter criteria.
-
#list_project_findings(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::ListFindingsResponse
Get a list of findings that meet the filter criteria.
-
#not_project_alert_actionable(name, mark_alert_as_not_actionable_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as not actionable - NOT_ACTIONABLE.
-
#read_project_alert(name, mark_alert_as_read_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as read - READ.
-
#resolve_project_alert(name, mark_alert_as_resolved_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert to closed state - RESOLVED.
-
#search_project_findings(parent, order_by: nil, page_size: nil, page_token: nil, query: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::SearchFindingsResponse
SearchFindings is a more powerful version of ListFindings that supports complex queries like "findings for alerts" using functions such as
has_alertin the query string. -
#track_project_alert_externally(name, mark_alert_as_tracked_externally_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as tracked externally - TRACKED_EXTERNALLY.
-
#triage_project_alert(name, mark_alert_as_triaged_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as triaged - TRIAGED.
-
#upsert_project_configuration(parent, configuration_object = nil, publish_time: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::UpsertConfigurationResponse
Creates or updates a configuration.
Constructor Details
#initialize ⇒ ThreatIntelligenceServiceService
Returns a new instance of ThreatIntelligenceServiceService.
47 48 49 50 51 52 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-threatintelligence_v1beta', client_version: Google::Apis::ThreatintelligenceV1beta::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#benign_project_alert(name, mark_alert_as_benign_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as benign - BENIGN.
110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 110 def benign_project_alert(name, mark_alert_as_benign_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:benign', ) command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsBenignRequest::Representation command.request_object = mark_alert_as_benign_request_object command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#duplicate_project_alert(name, mark_alert_as_duplicate_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as a duplicate of another alert. - DUPLICATE.
144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 144 def duplicate_project_alert(name, mark_alert_as_duplicate_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:duplicate', ) command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsDuplicateRequest::Representation command.request_object = mark_alert_as_duplicate_request_object command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enumerate_project_alert_facets(parent, filter: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::EnumerateAlertFacetsResponse
EnumerateAlertFacets returns the facets and the number of alerts that meet the filter criteria and have that value for each facet.
179 180 181 182 183 184 185 186 187 188 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 179 def enumerate_project_alert_facets(parent, filter: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/alerts:enumerateFacets', ) command.response_representation = Google::Apis::ThreatintelligenceV1beta::EnumerateAlertFacetsResponse::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::EnumerateAlertFacetsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#escalate_project_alert(name, mark_alert_as_escalated_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as escalated - ESCALATED.
212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 212 def escalate_project_alert(name, mark_alert_as_escalated_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:escalate', ) command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsEscalatedRequest::Representation command.request_object = mark_alert_as_escalated_request_object command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#false_project_alert_positive(name, mark_alert_as_false_positive_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as a false positive - FALSE_POSITIVE.
246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 246 def false_project_alert_positive(name, mark_alert_as_false_positive_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:falsePositive', ) command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsFalsePositiveRequest::Representation command.request_object = mark_alert_as_false_positive_request_object command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_project_org_profile_configuration(name, generate_org_profile_configuration_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Operation
Triggers the generation of a Customer Profile for a project.
76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 76 def generate_project_org_profile_configuration(name, generate_org_profile_configuration_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:generateOrgProfile', ) command.request_representation = Google::Apis::ThreatintelligenceV1beta::GenerateOrgProfileConfigurationRequest::Representation command.request_object = generate_org_profile_configuration_request_object command.response_representation = Google::Apis::ThreatintelligenceV1beta::Operation::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_alert(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Get an alert by name.
278 279 280 281 282 283 284 285 286 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 278 def get_project_alert(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_alert_document(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::AlertDocument
Gets a specific document associated with an alert.
539 540 541 542 543 544 545 546 547 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 539 def get_project_alert_document(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ThreatintelligenceV1beta::AlertDocument::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::AlertDocument command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_configuration(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Configuration
Get a configuration by name.
570 571 572 573 574 575 576 577 578 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 570 def get_project_configuration(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ThreatintelligenceV1beta::Configuration::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::Configuration command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_finding(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Finding
Get a finding by name. The name field should have the format: projects/
project/findings/finding``
725 726 727 728 729 730 731 732 733 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 725 def get_project_finding(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ThreatintelligenceV1beta::Finding::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::Finding command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_alerts(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::ListAlertsResponse
Get a list of alerts that meet the filter criteria.
334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 334 def list_project_alerts(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/alerts', ) command.response_representation = Google::Apis::ThreatintelligenceV1beta::ListAlertsResponse::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::ListAlertsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_configuration_revisions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::ListConfigurationRevisionsResponse
List configuration revisions that meet the filter criteria.
690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 690 def list_project_configuration_revisions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/revisions', ) command.response_representation = Google::Apis::ThreatintelligenceV1beta::ListConfigurationRevisionsResponse::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::ListConfigurationRevisionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_configurations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::ListConfigurationsResponse
Get a list of configurations that meet the filter criteria.
609 610 611 612 613 614 615 616 617 618 619 620 621 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 609 def list_project_configurations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/configurations', ) command.response_representation = Google::Apis::ThreatintelligenceV1beta::ListConfigurationsResponse::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::ListConfigurationsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_findings(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::ListFindingsResponse
Get a list of findings that meet the filter criteria. The parent field in
ListFindingsRequest should have the format: projects/project
765 766 767 768 769 770 771 772 773 774 775 776 777 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 765 def list_project_findings(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/findings', ) command.response_representation = Google::Apis::ThreatintelligenceV1beta::ListFindingsResponse::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::ListFindingsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#not_project_alert_actionable(name, mark_alert_as_not_actionable_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as not actionable - NOT_ACTIONABLE.
370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 370 def not_project_alert_actionable(name, mark_alert_as_not_actionable_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:notActionable', ) command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsNotActionableRequest::Representation command.request_object = mark_alert_as_not_actionable_request_object command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#read_project_alert(name, mark_alert_as_read_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as read - READ.
404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 404 def read_project_alert(name, mark_alert_as_read_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:read', ) command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsReadRequest::Representation command.request_object = mark_alert_as_read_request_object command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#resolve_project_alert(name, mark_alert_as_resolved_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert to closed state - RESOLVED.
438 439 440 441 442 443 444 445 446 447 448 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 438 def resolve_project_alert(name, mark_alert_as_resolved_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:resolve', ) command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsResolvedRequest::Representation command.request_object = mark_alert_as_resolved_request_object command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_project_findings(parent, order_by: nil, page_size: nil, page_token: nil, query: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::SearchFindingsResponse
SearchFindings is a more powerful version of ListFindings that supports
complex queries like "findings for alerts" using functions such as has_alert
in the query string. The parent field in SearchFindingsRequest should have
the format: projects/project Example to search for findings for a specific
issue: has_alert("name=\"projects/gti-12345/alerts/alert-12345\"")
815 816 817 818 819 820 821 822 823 824 825 826 827 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 815 def search_project_findings(parent, order_by: nil, page_size: nil, page_token: nil, query: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/findings:search', ) command.response_representation = Google::Apis::ThreatintelligenceV1beta::SearchFindingsResponse::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::SearchFindingsResponse command.params['parent'] = parent unless parent.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['query'] = query unless query.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#track_project_alert_externally(name, mark_alert_as_tracked_externally_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as tracked externally - TRACKED_EXTERNALLY.
472 473 474 475 476 477 478 479 480 481 482 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 472 def track_project_alert_externally(name, mark_alert_as_tracked_externally_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:trackExternally', ) command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsTrackedExternallyRequest::Representation command.request_object = mark_alert_as_tracked_externally_request_object command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#triage_project_alert(name, mark_alert_as_triaged_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::Alert
Marks an alert as triaged - TRIAGED.
506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 506 def triage_project_alert(name, mark_alert_as_triaged_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:triage', ) command.request_representation = Google::Apis::ThreatintelligenceV1beta::MarkAlertAsTriagedRequest::Representation command.request_object = mark_alert_as_triaged_request_object command.response_representation = Google::Apis::ThreatintelligenceV1beta::Alert::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::Alert command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#upsert_project_configuration(parent, configuration_object = nil, publish_time: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ThreatintelligenceV1beta::UpsertConfigurationResponse
Creates or updates a configuration.
649 650 651 652 653 654 655 656 657 658 659 660 |
# File 'lib/google/apis/threatintelligence_v1beta/service.rb', line 649 def upsert_project_configuration(parent, configuration_object = nil, publish_time: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/configurations:upsert', ) command.request_representation = Google::Apis::ThreatintelligenceV1beta::Configuration::Representation command.request_object = configuration_object command.response_representation = Google::Apis::ThreatintelligenceV1beta::UpsertConfigurationResponse::Representation command.response_class = Google::Apis::ThreatintelligenceV1beta::UpsertConfigurationResponse command.params['parent'] = parent unless parent.nil? command.query['publishTime'] = publish_time unless publish_time.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |